@@ -8,38 +8,40 @@
  */
 
 #include <afsconfig.h>
-#include "../afs/param.h"
+#include "afs/param.h"
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/DUX/osi_sleep.c,v 1.1.1.4 2001/07/14 22:19:36 hartmans Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/afs/DUX/Attic/osi_sleep.c,v 1.9 2003/07/15 23:14:19 shadow Exp $");
 
-#include "../afs/sysincludes.h"	/* Standard vendor system headers */
-#include "../afs/afsincludes.h"	/* Afs-based standard headers */
-#include "../afs/afs_stats.h"   /* afs statistics */
+#include "afs/sysincludes.h"	/* Standard vendor system headers */
+#include "afsincludes.h"	/* Afs-based standard headers */
+#include "afs/afs_stats.h"	/* afs statistics */
 
 
 
 static int osi_TimedSleep(char *event, afs_int32 ams, int aintok);
-void afs_osi_Wakeup(char *event);
-void afs_osi_Sleep(char *event);
 
 static char waitV;
 
 
-void afs_osi_InitWaitHandle(struct afs_osi_WaitHandle *achandle)
+void
+afs_osi_InitWaitHandle(struct afs_osi_WaitHandle *achandle)
 {
     AFS_STATCNT(osi_InitWaitHandle);
     achandle->proc = (caddr_t) 0;
 }
 
 /* cancel osi_Wait */
-void afs_osi_CancelWait(struct afs_osi_WaitHandle *achandle)
+void
+afs_osi_CancelWait(struct afs_osi_WaitHandle *achandle)
 {
     caddr_t proc;
 
     AFS_STATCNT(osi_CancelWait);
     proc = achandle->proc;
-    if (proc == 0) return;
-    achandle->proc = (caddr_t) 0;   /* so dude can figure out he was signalled */
+    if (proc == 0)
+	return;
+    achandle->proc = (caddr_t) 0;	/* so dude can figure out he was signalled */
     afs_osi_Wakeup(&waitV);
 }
 
@@ -47,13 +49,14 @@ void afs_osi_CancelWait(struct afs_osi_WaitHandle *achandle)
  * Waits for data on ahandle, or ams ms later.  ahandle may be null.
  * Returns 0 if timeout and EINTR if signalled.
  */
-int afs_osi_Wait(afs_int32 ams, struct afs_osi_WaitHandle *ahandle, int aintok)
+int
+afs_osi_Wait(afs_int32 ams, struct afs_osi_WaitHandle *ahandle, int aintok)
 {
     int code;
     afs_int32 endTime, tid;
 
     AFS_STATCNT(osi_Wait);
-    endTime = osi_Time() + (ams/1000);
+    endTime = osi_Time() + (ams / 1000);
     if (ahandle)
 	ahandle->proc = (caddr_t) u.u_procp;
     do {
@@ -61,7 +64,8 @@ int afs_osi_Wait(afs_int32 ams, struct afs_osi_WaitHandle *ahandle, int aintok)
 	code = 0;
 	code = osi_TimedSleep(&waitV, ams, aintok);
 
-	if (code) break;	/* if something happened, quit now */
+	if (code)
+	    break;		/* if something happened, quit now */
 	/* if we we're cancelled, quit now */
 	if (ahandle && (ahandle->proc == (caddr_t) 0)) {
 	    /* we've been signalled */
@@ -79,19 +83,20 @@ typedef struct afs_event {
     char *event;		/* lwp event: an address */
     int refcount;		/* Is it in use? */
     int seq;			/* Sequence number: this is incremented
-				   by wakeup calls; wait will not return until
-				   it changes */
+				 * by wakeup calls; wait will not return until
+				 * it changes */
     int cond;
 } afs_event_t;
 
 #define HASHSIZE 128
-afs_event_t *afs_evhasht[HASHSIZE];/* Hash table for events */
+afs_event_t *afs_evhasht[HASHSIZE];	/* Hash table for events */
 #define afs_evhash(event)	(afs_uint32) ((((long)event)>>2) & (HASHSIZE-1));
 int afs_evhashcnt = 0;
 
 /* Get and initialize event structure corresponding to lwp event (i.e. address)
  * */
-static afs_event_t *afs_getevent(char *event)
+static afs_event_t *
+afs_getevent(char *event)
 {
     afs_event_t *evp, *newp = 0;
     int hashcode;
@@ -109,7 +114,7 @@ static afs_event_t *afs_getevent(char *event)
 	evp = evp->next;
     }
     if (!newp) {
-	newp = (afs_event_t *) osi_AllocSmallSpace(sizeof (afs_event_t));
+	newp = (afs_event_t *) osi_AllocSmallSpace(sizeof(afs_event_t));
 	afs_evhashcnt++;
 	newp->next = afs_evhasht[hashcode];
 	afs_evhasht[hashcode] = newp;
@@ -124,7 +129,8 @@ static afs_event_t *afs_getevent(char *event)
 #define relevent(evp) ((evp)->refcount--)
 
 
-void afs_osi_Sleep(char *event)
+void
+afs_osi_Sleep(void *event)
 {
     struct afs_event *evp;
     int seq;
@@ -133,7 +139,7 @@ void afs_osi_Sleep(char *event)
     seq = evp->seq;
     while (seq == evp->seq) {
 	AFS_ASSERT_GLOCK();
-	assert_wait((vm_offset_t)(&evp->cond), 0);
+	assert_wait((vm_offset_t) (&evp->cond), 0);
 	AFS_GUNLOCK();
 	thread_block();
 	AFS_GLOCK();
@@ -141,6 +147,13 @@ void afs_osi_Sleep(char *event)
     relevent(evp);
 }
 
+int
+afs_osi_SleepSig(void *event)
+{
+    afs_osi_Sleep(event);
+    return 0;
+}
+
 /* osi_TimedSleep
  * 
  * Arguments:
@@ -150,38 +163,43 @@ void afs_osi_Sleep(char *event)
  *
  * Returns 0 if timeout and EINTR if signalled.
  */
-static int osi_TimedSleep(char *event, afs_int32 ams, int aintok)
+static int
+osi_TimedSleep(char *event, afs_int32 ams, int aintok)
 {
     int code = 0;
     struct afs_event *evp;
     int ticks;
 
-    ticks = ( ams * afs_hz )/1000;
+    ticks = (ams * afs_hz) / 1000;
 
 
     evp = afs_getevent(event);
 
-    assert_wait((vm_offset_t)(&evp->cond), aintok);
+    assert_wait((vm_offset_t) (&evp->cond), aintok);
     AFS_GUNLOCK();
     thread_set_timeout(ticks);
     thread_block();
     AFS_GLOCK();
     if (current_thread()->wait_result != THREAD_AWAKENED)
 	code = EINTR;
-    
+
     relevent(evp);
     return code;
 }
 
 
-void afs_osi_Wakeup(char *event)
+int
+afs_osi_Wakeup(void *event)
 {
+    int ret = 1;
     struct afs_event *evp;
 
     evp = afs_getevent(event);
     if (evp->refcount > 1) {
-	evp->seq++;    
-	thread_wakeup((vm_offset_t)(&evp->cond));
+	evp->seq++;
+	thread_wakeup((vm_offset_t) (&evp->cond));
+	ret = 0;
     }
     relevent(evp);
+    return ret;
 }
