@@ -2,7 +2,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/FBSD/osi_vfsops.c,v 1.16.2.1 2004/11/09 17:11:34 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/FBSD/osi_vfsops.c,v 1.16.2.5 2005/07/11 19:27:27 shadow Exp $");
 
 #include <afs/sysincludes.h>	/* Standard vendor system headers */
 #include <afsincludes.h>	/* Afs-based standard headers */
@@ -10,7 +10,10 @@ RCSID
 #include <sys/malloc.h>
 #include <sys/namei.h>
 #include <sys/conf.h>
+#include <sys/module.h>
+#include <sys/sysproto.h>
 #include <sys/syscall.h>
+#include <sys/sysent.h>
 
 struct vcache *afs_globalVp = NULL;
 struct mount *afs_globalVFS = NULL;
@@ -22,23 +25,53 @@ int afs_pbuf_freecnt = -1;
 #define	THREAD_OR_PROC struct proc *p
 #endif
 
+extern int afs3_syscall();
+extern int Afs_xsetgroups();
+extern int afs_xioctl();
+
+static sy_call_t *old_handler;
+
+
+int
+afs_init(struct vfsconf *vfc)
+{
+    if (sysent[AFS_SYSCALL].sy_call != nosys
+	&& sysent[AFS_SYSCALL].sy_call != lkmnosys) {
+	printf("AFS_SYSCALL in use. aborting\n");
+	return EBUSY;
+    }
+    osi_Init();
+    afs_pbuf_freecnt = nswbuf / 2 + 1;
+#if 0
+    sysent[SYS_setgroups].sy_call = Afs_xsetgroups;
+    sysent[SYS_ioctl].sy_call = afs_xioctl;
+#endif
+    old_handler = sysent[AFS_SYSCALL].sy_call;
+    sysent[AFS_SYSCALL].sy_call = afs3_syscall;
+    sysent[AFS_SYSCALL].sy_narg = 5;
+    return 0;
+}
+
+int
+afs_uninit(struct vfsconf *vfc)
+{
+    if (afs_globalVFS)
+	return EBUSY;
+#if 0
+    sysent[SYS_ioctl].sy_call = ioctl;
+    sysent[SYS_setgroups].sy_call = setgroups;
+#endif
+    sysent[AFS_SYSCALL].sy_narg = 0;
+    sysent[AFS_SYSCALL].sy_call = old_handler;
+    return 0;
+}
+
 int
 afs_start(struct mount *mp, int flags, THREAD_OR_PROC)
 {
-    afs_pbuf_freecnt = nswbuf / 2 + 1;
     return (0);			/* nothing to do. ? */
 }
 
-#ifdef AFS_FBSD53_ENV
-int
-afs_mount(struct mount *mp, struct thread *td)
-{
-    int afs_omount(struct mount *mp, char *path, caddr_t data, struct thread *p);
-
-    return afs_omount(mp, NULL, NULL, td);
-}
-#endif
-
 int
 #ifdef AFS_FBSD53_ENV
 afs_omount(struct mount *mp, char *path, caddr_t data, struct thread *p)
@@ -67,18 +100,36 @@ afs_omount(struct mount *mp, char *path, caddr_t data, struct nameidata *ndp,
     vfs_getnewfsid(mp);
     mp->mnt_stat.f_iosize = 8192;
 
-    if (path)
-	(void) copyinstr(path, mp->mnt_stat.f_mntonname, MNAMELEN - 1, &size);
+    if (path != NULL)
+	copyinstr(path, mp->mnt_stat.f_mntonname, MNAMELEN - 1, &size);
+    else
+	bcopy("/afs", mp->mnt_stat.f_mntonname, size = 4);
     memset(mp->mnt_stat.f_mntonname + size, 0, MNAMELEN - size);
     memset(mp->mnt_stat.f_mntfromname, 0, MNAMELEN);
     strcpy(mp->mnt_stat.f_mntfromname, "AFS");
     /* null terminated string "AFS" will fit, just leave it be. */
     strcpy(mp->mnt_stat.f_fstypename, "afs");
     AFS_GUNLOCK();
-    (void)afs_statfs(mp, &mp->mnt_stat, p);
+    afs_statfs(mp, &mp->mnt_stat, p);
     return 0;
 }
 
+#ifdef AFS_FBSD53_ENV
+int
+afs_mount(struct mount *mp, struct thread *td)
+{
+    return afs_omount(mp, NULL, NULL, td);
+}
+#endif
+
+#ifdef AFS_FBSD60_ENV
+static int
+afs_cmount(struct mntarg *ma, void *data, int flags, struct thread *td)
+{
+    return kernel_mount(ma, flags);
+}
+#endif
+
 int
 afs_unmount(struct mount *mp, int flags, THREAD_OR_PROC)
 {
@@ -104,7 +155,9 @@ afs_unmount(struct mount *mp, int flags, THREAD_OR_PROC)
 }
 
 int
-#ifdef AFS_FBSD53_ENV
+#if defined(AFS_FBSD60_ENV)
+afs_root(struct mount *mp, int flags, struct vnode **vpp, struct thread *td)
+#elif defined(AFS_FBSD53_ENV)
 afs_root(struct mount *mp, struct vnode **vpp, struct thread *td)
 #else
 afs_root(struct mount *mp, struct vnode **vpp)
@@ -173,7 +226,7 @@ tryagain:
 	*vpp = vp;
     }
 
-    afs_Trace2(afs_iclSetp, CM_TRACE_VFSROOT, ICL_TYPE_POINTER, *vpp,
+    afs_Trace2(afs_iclSetp, CM_TRACE_VFSROOT, ICL_TYPE_POINTER, tvp ? AFSTOV(tvp) : NULL,
 	       ICL_TYPE_INT32, error);
     AFS_GUNLOCK();
     crfree(cr);
@@ -211,17 +264,28 @@ afs_statfs(struct mount *mp, struct statfs *abp, THREAD_OR_PROC)
 }
 
 int
+#ifdef AFS_FBSD60_ENV
+afs_sync(struct mount *mp, int waitfor, struct thread *td)
+#else
 afs_sync(struct mount *mp, int waitfor, struct ucred *cred, THREAD_OR_PROC)
+#endif
 {
     return 0;
 }
 
-int
-afs_init(struct vfsconf *vfc)
-{
-    return 0;
-}
-
+#ifdef AFS_FBSD60_ENV
+struct vfsops afs_vfsops = {
+	.vfs_init =		afs_init,
+	.vfs_mount =		afs_mount,
+	.vfs_cmount =		afs_cmount,
+	.vfs_root =		afs_root,
+	.vfs_statfs =		afs_statfs,
+	.vfs_sync =		afs_sync,
+	.vfs_uninit =		afs_uninit,
+	.vfs_unmount =		afs_unmount,
+	.vfs_sysctl =		vfs_stdsysctl,
+};
+#else
 struct vfsops afs_vfsops = {
 #ifdef AFS_FBSD53_ENV
     afs_mount,
@@ -238,9 +302,10 @@ struct vfsops afs_vfsops = {
     vfs_stdcheckexp,
     vfs_stdvptofh,
     afs_init,
-    vfs_stduninit,
+    afs_uninit,
     vfs_stdextattrctl,
 #ifdef AFS_FBSD50_ENV
     vfs_stdsysctl,
 #endif
 };
+#endif
