@@ -15,7 +15,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_syscall.c,v 1.1.2.5 2005/04/03 19:32:39 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_syscall.c,v 1.1.2.7 2005/11/02 00:28:17 shadow Exp $");
 
 #ifdef AFS_LINUX24_ENV
 #include <linux/module.h> /* early to avoid printf->printk mapping */
@@ -26,7 +26,7 @@ RCSID
 #include "h/mm.h"
 
 #ifdef AFS_AMD64_LINUX20_ENV
-#include "../asm/ia32_unistd.h"
+#include <asm/ia32_unistd.h>
 #endif
 
 #include <linux/proc_fs.h>
@@ -128,19 +128,33 @@ static void sys32_setgroups_stub()
 
 /***** SPARC64 *****/
 #ifdef AFS_SPARC64_LINUX20_ENV
+#ifdef AFS_SPARC64_LINUX26_ENV
+static SYSCALLTYPE *afs_sys_call_table32;
+#else
 extern SYSCALLTYPE *afs_sys_call_table32;
+#endif
 static SYSCALLTYPE afs_ni_syscall32 = 0;
 
 extern int afs32_xsetgroups();
+#ifdef AFS_SPARC64_LINUX26_ENV
+asmlinkage int (*sys32_setgroupsp) (int gidsetsize,
+				    __kernel_gid32_t * grouplist);
+#else
 asmlinkage int (*sys32_setgroupsp) (int gidsetsize,
 				    __kernel_gid_t32 * grouplist);
+#endif
 #ifdef AFS_LINUX24_ENV
 /* This number is not exported for some bizarre reason. */
 #define __NR_setgroups32      82
 extern int afs32_xsetgroups32();
+#ifdef AFS_SPARC64_LINUX26_ENV
+asmlinkage int (*sys32_setgroups32p) (int gidsetsize,
+				      __kernel_gid32_t * grouplist);
+#else
 asmlinkage int (*sys32_setgroups32p) (int gidsetsize,
 				      __kernel_gid_t32 * grouplist);
 #endif
+#endif
 
 asmlinkage int
 afs_syscall32(long syscall, long parm1, long parm2, long parm3, long parm4,
