@@ -22,7 +22,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.81.2.36 2005/09/04 04:11:55 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.81.2.46 2006/10/10 22:01:04 shadow Exp $");
 
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
@@ -75,7 +75,11 @@ afs_linux_read(struct file *fp, char *buf, size_t count, loff_t * offp)
     else {
 	    osi_FlushPages(vcp, credp);	/* ensure stale pages are gone */
 	    AFS_GUNLOCK();
+#ifdef DO_SYNC_READ
+	    code = do_sync_read(fp, buf, count, offp);
+#else
 	    code = generic_file_read(fp, buf, count, offp);
+#endif
 	    AFS_GLOCK();
     }
 
@@ -121,17 +125,16 @@ afs_linux_write(struct file *fp, const char *buf, size_t count, loff_t * offp)
 	code = -code;
     else {
 	    AFS_GUNLOCK();
+#ifdef DO_SYNC_READ
+	    code = do_sync_write(fp, buf, count, offp);
+#else
 	    code = generic_file_write(fp, buf, count, offp);
+#endif
 	    AFS_GLOCK();
     }
 
     ObtainWriteLock(&vcp->lock, 530);
-    vcp->m.Date = osi_Time();	/* set modification time */
     afs_FakeClose(vcp, credp);
-    if (code >= 0)
-	code2 = afs_DoPartialWrite(vcp, &treq);
-    if (code2 && code >= 0)
-	code = (ssize_t) - code2;
     ReleaseWriteLock(&vcp->lock);
 
     afs_Trace4(afs_iclSetp, CM_TRACE_WRITEOP, ICL_TYPE_POINTER, vcp,
@@ -468,6 +471,27 @@ afs_linux_lock(struct file *fp, int cmd, struct file_lock *flp)
     code = afs_lockctl(vcp, &flock, cmd, credp);
     AFS_GUNLOCK();
 
+#ifdef AFS_LINUX24_ENV
+    if (code == 0 && (cmd == F_SETLK || cmd == F_SETLKW)) {
+#ifdef AFS_LINUX26_ENV
+       struct file_lock flp2;
+       flp2 = *flp;
+       flp2.fl_flags &=~ FL_SLEEP;
+       code = posix_lock_file(fp, &flp2);
+#else
+       code = posix_lock_file(fp, flp, 0);
+#endif 
+       osi_Assert(code != -EAGAIN); /* there should be no conflicts */
+       if (code) {
+           struct AFS_FLOCK flock2;
+           flock2 = flock;
+           flock2.l_type = F_UNLCK;
+           AFS_GLOCK();
+           afs_lockctl(vcp, &flock2, F_SETLK, credp);
+           AFS_GUNLOCK();
+       }
+    }
+#endif
     /* Convert flock back to Linux's file_lock */
     flp->fl_type = flock.l_type;
     flp->fl_pid = flock.l_pid;
@@ -549,6 +573,10 @@ struct file_operations afs_dir_fops = {
 struct file_operations afs_file_fops = {
   .read =	afs_linux_read,
   .write =	afs_linux_write,
+#ifdef GENERIC_FILE_AIO_READ
+  .aio_read =	generic_file_aio_read,
+  .aio_write =	generic_file_aio_write,
+#endif
 #ifdef HAVE_UNLOCKED_IOCTL
   .unlocked_ioctl = afs_unlocked_xioctl,
 #else
@@ -793,8 +821,7 @@ afs_dentry_iput(struct dentry *dp, struct inode *ip)
     struct vcache *vcp = VTOAFS(ip);
 
     AFS_GLOCK();
-    if (vcp->states & CUnlinked)
-	(void) afs_InactiveVCache(vcp, NULL);
+    (void) afs_InactiveVCache(vcp, NULL);
     AFS_GUNLOCK();
 
     iput(ip);
@@ -884,11 +911,9 @@ static int
 afs_linux_lookup(struct inode *dip, struct dentry *dp)
 #endif
 {
-    struct vattr vattr;
     cred_t *credp = crref();
     struct vcache *vcp = NULL;
     const char *comp = dp->d_name.name;
-    struct dentry *res = NULL;
     struct inode *ip = NULL;
     int code;
 
@@ -899,24 +924,33 @@ afs_linux_lookup(struct inode *dip, struct dentry *dp)
     code = afs_lookup(VTOAFS(dip), comp, &vcp, credp);
     
     if (vcp) {
-	ip = AFSTOV(vcp);
+	struct vattr vattr;
 
+	ip = AFSTOV(vcp);
 	afs_getattr(vcp, &vattr, credp);
 	afs_fill_inode(ip, &vattr);
     }
     dp->d_op = &afs_dentry_operations;
     dp->d_time = hgetlo(VTOAFS(dip)->m.DataVersion);
     AFS_GUNLOCK();
+
 #if defined(AFS_LINUX24_ENV)
     if (ip && S_ISDIR(ip->i_mode)) {
-            d_prune_aliases(ip);
-            res = d_find_alias(ip);
+	struct dentry *alias;
+
+	alias = d_find_alias(ip);
+	if (alias) {
+	    if (d_invalidate(alias) == 0) {
+		dput(alias);
+	    } else {
+		iput(ip);
+#if defined(AFS_LINUX26_ENV)
+		unlock_kernel();
+#endif
+		return alias;
+	    }
+	}
     }
-    if (res) {
-	if (d_unhashed(res))
-	    d_rehash(res);
-	iput(ip);
-    } else
 #endif
     d_add(dp, ip);
 
@@ -928,10 +962,6 @@ afs_linux_lookup(struct inode *dip, struct dentry *dp)
     /* It's ok for the file to not be found. That's noted by the caller by
      * seeing that the dp->d_inode field is NULL.
      */
-#if defined(AFS_LINUX24_ENV)
-    if (code == 0)
-        return res;
-#endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,2,10)
     if (code == ENOENT)
 	return ERR_PTR(0);
@@ -1374,9 +1404,7 @@ afs_linux_writepage_sync(struct inode *ip, struct page *pp,
     ip->i_size = vcp->m.Length;
     ip->i_blocks = ((vcp->m.Length + 1023) >> 10) << 1;
 
-    if (!code
-	&& afs_stats_cmperf.cacheCurrDirtyChunks >
-	afs_stats_cmperf.cacheMaxDirtyChunks) {
+    if (!code) {
 	struct vrequest treq;
 
 	ObtainWriteLock(&vcp->lock, 533);
@@ -1414,7 +1442,11 @@ afs_linux_writepage(struct page *pp)
 
 #if defined(AFS_LINUX26_ENV)
     if (PageReclaim(pp)) {
+# if defined(WRITEPAGE_ACTIVATE)
 	return WRITEPAGE_ACTIVATE;
+# else 
+	return AOP_WRITEPAGE_ACTIVATE;
+# endif
     }
 #else
     if (PageLaunder(pp)) {
@@ -1475,6 +1507,16 @@ afs_linux_updatepage(struct file *fp, struct page *pp, unsigned long offset,
     ip->i_size = vcp->m.Length;
     ip->i_blocks = ((vcp->m.Length + 1023) >> 10) << 1;
 
+    if (!code) {
+	struct vrequest treq;
+
+	ObtainWriteLock(&vcp->lock, 533);
+	vcp->m.Date = osi_Time();   /* set modification time */
+	if (!afs_InitReq(&treq, credp))
+	    code = afs_DoPartialWrite(vcp, &treq);
+	ReleaseWriteLock(&vcp->lock);
+    }
+
     code = code ? -code : count - tuio.uio_resid;
     afs_Trace4(afs_iclSetp, CM_TRACE_UPDATEPAGE, ICL_TYPE_POINTER, vcp,
 	       ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, page_count(pp),
