@@ -16,15 +16,13 @@
  * afs_osi.h.
  */
 
-/* $Id: osi_machdep.h,v 1.16.2.1 2005/03/11 06:50:43 shadow Exp $ */
+/* $Id: osi_machdep.h,v 1.16.2.7 2006/06/23 14:21:12 rees Exp $ */
 
 #ifndef _OSI_MACHDEP_H_
 #define _OSI_MACHDEP_H_
 
 #include <sys/lock.h>
 
-extern struct simplelock afs_rxglobal_lock;
-
 #define M_AFSFID	(M_TEMP-1)
 #define M_AFSBUFHDR	(M_TEMP-2)
 #define M_AFSBUFFER	(M_TEMP-3)
@@ -40,16 +38,11 @@ extern struct simplelock afs_rxglobal_lock;
 #define v_vfsp		v_mount
 
 /* vnode */
-#define SetAfsVnode(vn)		/* nothing; done in getnewvnode() */
-#define IsAfsVnode(vn)	((vn)->v_op == afs_vnodeop_p)
 #define VN_HOLD(vp)	afs_vget((vp), 0)
 #define VN_RELE(vp)	vrele(vp)
 #define osi_vnhold(avc, r) afs_vget(AFSTOV(avc), 0)
 #define va_nodeid	va_fileid
 #define vnode_t		struct vnode
-#define vSetType(vc, type)	AFSTOV(vc)->v_type = (type)
-#define vSetVfsp(vc, vfsp)	AFSTOV(vc)->v_mount = (vfsp)
-#define vType(vc)		(vc)->v->v_type
 
 /* uio */
 #define afsio_iov	uio_iov
@@ -74,7 +67,6 @@ extern struct simplelock afs_rxglobal_lock;
 #define p_rcred         p_ucred
 
 /* time */
-extern struct timeval time;
 #define	afs_hz		hz
 #define osi_GetTime(x)	microtime(x)
 #define osi_Time()	(time.tv_sec)
@@ -108,40 +100,45 @@ extern void *afs_nbsd_Alloc(size_t asize);
 extern void afs_nbsd_Free(void *p, size_t asize);
 extern int afs_vget();
 
+#undef gop_lookupname
 #define	gop_lookupname(fnamep, segflg, followlink, compvpp) \
 	afs_nbsd_lookupname((fnamep), (segflg), (followlink), (compvpp))
 
-#ifdef KERNEL
-extern int (**afs_vnodeop_p) ();
+#ifdef AFS_OBSD39_ENV
+#define afs_osi_lockmgr(l, f, i, p) lockmgr((l), (f), (i))
+#else
+#define afs_osi_lockmgr(l, f, i, p) lockmgr((l), (f), (i), (p))
+#endif
 
+#ifdef KERNEL
+
+#define AFS_GLOCK() AFS_GLOCKP(curproc)
+#define AFS_GUNLOCK() AFS_GUNLOCKP(curproc)
 #ifdef AFS_GLOBAL_SUNLOCK
 extern struct proc *afs_global_owner;
 extern struct lock afs_global_lock;
-#define AFS_GLOCK() \
+#define AFS_GLOCKP(p) \
     do { \
-        osi_Assert(curproc); \
- 	lockmgr(&afs_global_lock, LK_EXCLUSIVE, 0, curproc); \
+        osi_Assert(p); \
+ 	afs_osi_lockmgr(&afs_global_lock, LK_EXCLUSIVE, 0, (p)); \
         osi_Assert(afs_global_owner == NULL); \
-   	afs_global_owner = curproc; \
+   	afs_global_owner = (p); \
     } while (0)
-#define AFS_GUNLOCK() \
+#define AFS_GUNLOCKP(p) \
     do { \
-        osi_Assert(curproc); \
- 	osi_Assert(afs_global_owner == curproc); \
+        osi_Assert(p); \
+ 	osi_Assert(afs_global_owner == (p)); \
         afs_global_owner = NULL; \
-        lockmgr(&afs_global_lock, LK_RELEASE, 0, curproc); \
+        afs_osi_lockmgr(&afs_global_lock, LK_RELEASE, 0, (p)); \
     } while(0)
 #define ISAFS_GLOCK() (afs_global_owner == curproc && curproc)
 #else
-extern struct simplelock afs_global_lock;
-#define AFS_GLOCK()
-#define AFS_GUNLOCK()
+extern struct lock afs_global_lock;
+#define AFS_GLOCKP(p)
+#define AFS_GUNLOCKP(p)
 #define AFS_ASSERT_GLOCK()
 #define ISAFS_GLOCK() 1
 #endif
-#define AFS_RXGLOCK()
-#define AFS_RXGUNLOCK()
-#define ISAFS_RXGLOCK() 1
 
 #undef SPLVAR
 #define SPLVAR int splvar
