@@ -23,7 +23,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_readdir.c,v 1.24.2.5 2005/04/03 18:15:39 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_readdir.c,v 1.24.2.8 2005/11/19 04:35:42 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -143,7 +143,12 @@ struct irix5_min_dirent {	/* miniature dirent structure */
 #else
 struct min_direct {		/* miniature direct structure */
     /* If struct direct changes, this must too */
-#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
+#if defined(AFS_DARWIN80_ENV)
+    ino_t d_fileno;
+    u_short d_reclen;
+    u_char d_type;
+    u_char d_namlen;
+#elif defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     afs_uint32 d_fileno;
     u_short d_reclen;
     u_char d_type;
@@ -242,7 +247,10 @@ afs_readdir_type(avc, ade)
     tfid.Fid.Unique = ntohl(ade->fid.vunique);
     if ((avc->states & CForeign) == 0 && (ntohl(ade->fid.vnode) & 1)) {
 	return DT_DIR;
-    } else if ((tvc = afs_FindVCache(&tfid, 0, 0))) {
+    }
+    ObtainReadLock(&afs_xvcache);
+    if ((tvc = afs_FindVCache(&tfid, 0, 0))) {
+        ReleaseReadLock(&afs_xvcache);
 	if (tvc->mvstat) {
 	    afs_PutVCache(tvc);
 	    return DT_DIR;
@@ -261,7 +269,8 @@ afs_readdir_type(avc, ade)
 	    /* what other types does AFS support? */
 	} else
 	    afs_PutVCache(tvc);
-    }
+    } else
+        ReleaseReadLock(&afs_xvcache);
     return DT_UNKNOWN;
 }
 #endif
@@ -580,8 +589,9 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 #if defined(AFS_SGI53_ENV)
     afs_int32 use64BitDirent, dirsiz;
 #endif /* defined(AFS_SGI53_ENV) */
+#ifndef	AFS_HPUX_ENV
     OSI_VC_CONVERT(avc);
-#ifdef	AFS_HPUX_ENV
+#else
     /*
      * XXX All the hacks for alloced sdirEntry and inlining of afs_readdir_move instead of calling
      * it is necessary for hpux due to stack problems that seem to occur when coming thru the nfs
@@ -625,7 +635,7 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 	*eofp = 0;
 #endif
     if (AfsLargeFileUio(auio)	/* file is large than 2 GB */
-	||AfsLargeFileSize(auio->uio_offset, auio->uio_resid))
+	||AfsLargeFileSize(AFS_UIO_OFFSET(auio), AFS_UIO_RESID(auio)))
 	return EFBIG;
 
     if ((code = afs_InitReq(&treq, acred))) {
@@ -709,7 +719,7 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
     auio->uio_fpflags = 0;
 #endif
     while (code == 0) {
-	origOffset = auio->afsio_offset;
+	origOffset = AFS_UIO_OFFSET(auio);
 	/* scan for the next interesting entry scan for in-use blob otherwise up point at
 	 * this blob note that ode, if non-zero, also represents a held dir page */
 	if (!(us = BlobScan(tdc, (origOffset >> 5)))
@@ -721,7 +731,7 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 		sdirEntry->d_fileno =
 		    (avc->fid.Fid.Volume << 16) + ntohl(ode->fid.vnode);
 		FIXUPSTUPIDINODE(sdirEntry->d_fileno);
-		sdirEntry->d_reclen = rlen = auio->afsio_resid;
+		sdirEntry->d_reclen = rlen = AFS_UIO_RESID(auio);
 		sdirEntry->d_namlen = o_slen;
 #if defined(AFS_SUN5_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_HPUX100_ENV)
 		sdirEntry->d_off = origOffset;
@@ -751,11 +761,11 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 #if defined(AFS_SUN5_ENV)
 					len, origOffset);
 #else
-					auio->afsio_resid, origOffset);
+					AFS_UIO_RESID(auio), origOffset);
 #endif
 #endif /* AFS_HPUX_ENV */
 #if !defined(AFS_SUN5_ENV)
-		auio->afsio_resid = 0;
+		AFS_UIO_SETRESID(auio, 0);
 #endif
 	    } else {
 		/* nothin to hand over */
@@ -779,9 +789,9 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 #ifdef	AFS_SGI53_ENV
 	dirsiz =
 	    use64BitDirent ? DIRENTSIZE(n_slen) : IRIX5_DIRENTSIZE(n_slen);
-	if (dirsiz >= (auio->afsio_resid - len)) {
+	if (dirsiz >= (AFS_UIO_RESID(auio) - len)) {
 #else
-	if (DIRSIZ_LEN(n_slen) >= (auio->afsio_resid - len)) {
+	if (DIRSIZ_LEN(n_slen) >= (AFS_UIO_RESID(auio) - len)) {
 #endif /* AFS_SGI53_ENV */
 	    /* No can do no more now; ya know... at this time */
 	    DRelease((struct buffer *)nde, 0);	/* can't use this one. */
@@ -790,7 +800,7 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 		sdirEntry->d_fileno =
 		    (avc->fid.Fid.Volume << 16) + ntohl(ode->fid.vnode);
 		FIXUPSTUPIDINODE(sdirEntry->d_fileno);
-		sdirEntry->d_reclen = rlen = auio->afsio_resid;
+		sdirEntry->d_reclen = rlen = AFS_UIO_RESID(auio);
 		sdirEntry->d_namlen = o_slen;
 #if defined(AFS_SUN5_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_HPUX100_ENV)
 		sdirEntry->d_off = origOffset;
@@ -818,12 +828,12 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 #else /* AFS_HPUX_ENV */
 		code =
 		    afs_readdir_move(ode, avc, auio, o_slen,
-				     auio->afsio_resid, origOffset);
+				     AFS_UIO_RESID(auio), origOffset);
 #endif /* AFS_HPUX_ENV */
 		/* this next line used to be AFSVFS40 or AIX 3.1, but is
 		 * really generic */
-		auio->afsio_offset = origOffset;
-		auio->afsio_resid = 0;
+		AFS_UIO_SETOFFSET(auio, origOffset);
+		AFS_UIO_SETRESID(auio, 0);
 	    } else {		/* trouble, can't give anything to the user! */
 		/* even though he has given us a buffer, 
 		 * even though we have something to give us,
@@ -884,8 +894,7 @@ afs_readdir(OSI_VC_ARG(avc), auio, acred)
 	if (ode)
 	    DRelease((struct buffer *)ode, 0);
 	ode = nde;
-	auio->afsio_offset =
-	    (afs_int32) ((us + afs_dir_NameBlobs(nde->name)) << 5);
+	AFS_UIO_SETOFFSET(auio, (afs_int32) ((us + afs_dir_NameBlobs(nde->name)) << 5));
     }
     if (ode)
 	DRelease((struct buffer *)ode, 0);
@@ -999,7 +1008,7 @@ afs1_readdir(avc, auio, acred)
     auio->uio_fpflags = 0;
 #endif
     while (code == 0) {
-	origOffset = auio->afsio_offset;
+	origOffset = AFS_UIO_OFFSET(auio);
 
 	/* scan for the next interesting entry scan for in-use blob otherwise up point at
 	 * this blob note that ode, if non-zero, also represents a held dir page */
@@ -1012,7 +1021,7 @@ afs1_readdir(avc, auio, acred)
 		sdirEntry->d_fileno =
 		    (avc->fid.Fid.Volume << 16) + ntohl(ode->fid.vnode);
 		FIXUPSTUPIDINODE(sdirEntry->d_fileno);
-		sdirEntry->d_reclen = rlen = auio->afsio_resid;
+		sdirEntry->d_reclen = rlen = AFS_UIO_RESID(auio);
 		sdirEntry->d_namlen = o_slen;
 		sdirEntry->d_off = origOffset;
 		AFS_UIOMOVE((char *)sdirEntry, sizeof(*sdirEntry), UIO_READ,
@@ -1039,9 +1048,9 @@ afs1_readdir(avc, auio, acred)
 #else
 		code =
 		    afs_readdir_move(ode, avc, auio, o_slen,
-				     auio->afsio_resid, origOffset);
+				     AFS_UIO_RESID(auio), origOffset);
 #endif /* AFS_HPUX_ENV */
-		auio->afsio_resid = 0;
+		AFS_UIO_SETRESID(auio, 0);
 	    } else {
 		/* nothin to hand over */
 	    }
@@ -1061,7 +1070,7 @@ afs1_readdir(avc, auio, acred)
 #else
 	n_slen = strlen(nde->name);
 #endif
-	if (NDIRSIZ_LEN(n_slen) >= (auio->afsio_resid - len)) {
+	if (NDIRSIZ_LEN(n_slen) >= (AFS_UIO_RESID(auio) - len)) {
 	    /* No can do no more now; ya know... at this time */
 	    DRelease(nde, 0);	/* can't use this one. */
 	    if (len) {
@@ -1069,7 +1078,7 @@ afs1_readdir(avc, auio, acred)
 		sdirEntry->d_fileno =
 		    (avc->fid.Fid.Volume << 16) + ntohl(ode->fid.vnode);
 		FIXUPSTUPIDINODE(sdirEntry->d_fileno);
-		sdirEntry->d_reclen = rlen = auio->afsio_resid;
+		sdirEntry->d_reclen = rlen = AFS_UIO_RESID(auio);
 		sdirEntry->d_namlen = o_slen;
 		sdirEntry->d_off = origOffset;
 		AFS_UIOMOVE((char *)sdirEntry, sizeof(*sdirEntry), UIO_READ,
@@ -1095,11 +1104,11 @@ afs1_readdir(avc, auio, acred)
 #else
 		code =
 		    afs_readdir_move(ode, avc, auio, o_slen,
-				     auio->afsio_resid, origOffset);
+				     AFS_UIO_RESID(auio), origOffset);
 #endif /* AFS_HPUX_ENV */
 		/* this next line used to be AFSVFS40 or AIX 3.1, but is really generic */
-		auio->afsio_offset = origOffset;
-		auio->afsio_resid = 0;
+		AFS_UIO_SETOFFSET(auio, origOffset);
+		AFS_UIO_SETRESID(auio, 0);
 	    } else {		/* trouble, can't give anything to the user! */
 		/* even though he has given us a buffer, 
 		 * even though we have something to give us,
@@ -1152,7 +1161,7 @@ afs1_readdir(avc, auio, acred)
 	if (ode)
 	    DRelease(ode, 0);
 	ode = nde;
-	auio->afsio_offset = ((us + afs_dir_NameBlobs(nde->name)) << 5);
+	AFS_UIO_OFFSET(auio) = ((us + afs_dir_NameBlobs(nde->name)) << 5);
     }
     if (ode)
 	DRelease(ode, 0);
