@@ -43,7 +43,7 @@ extern int afs_shuttingdown;
 #if     defined(AFS_HPUX102_ENV)
 #define AFS_FLOCK       k_flock
 #else
-#if     defined(AFS_SUN56_ENV) || (defined(AFS_LINUX24_ENV) && !defined(AFS_PPC64_LINUX26_ENV) && !defined(AFS_AMD64_LINUX26_ENV) && !defined(AFS_IA64_LINUX26_ENV) && !defined(AFS_S390X_LINUX26_ENV) && !defined(AFS_ALPHA_LINUX26_ENV))
+#if     defined(AFS_SUN56_ENV) || (defined(AFS_LINUX24_ENV) && !(defined(AFS_LINUX26_ENV) && defined(AFS_LINUX_64BIT_KERNEL)))
 #define AFS_FLOCK       flock64
 #else
 #define AFS_FLOCK       flock
@@ -315,7 +315,7 @@ struct conn {
 #define	QInit(q)    ((q)->prev = (q)->next = (q))
 #define	QAdd(q,e)   ((e)->next = (q)->next, (e)->prev = (q), \
 			(q)->next->prev = (e), (q)->next = (e))
-#define	QRemove(e)  ((e)->next->prev = (e)->prev, (e)->prev->next = (e)->next)
+#define	QRemove(e)  ((e)->next->prev = (e)->prev, (e)->prev->next = (e)->next, (e)->prev = NULL, (e)->next = NULL)
 #define	QNext(e)    ((e)->next)
 #define QPrev(e)    ((e)->prev)
 #define QEmpty(q)   ((q)->prev == (q))
@@ -329,6 +329,7 @@ struct conn {
  */
 #define	QTOV(e)	    ((struct vcache *)(((char *) (e)) - (((char *)(&(((struct vcache *)(e))->vlruq))) - ((char *)(e)))))
 #define	QTOC(e)	    ((struct cell *)((char *) (e)))
+#define	QTOVH(e)   ((struct vcache *)(((char *) (e)) - (((char *)(&(((struct vcache *)(e))->vhashq))) - ((char *)(e)))))
 
 #define	SRVADDR_MH	1
 #define	SRVADDR_ISDOWN	0x20	/* same as SRVR_ISDOWN */
@@ -526,12 +527,16 @@ struct SimpleLocks {
 #ifdef	AFS_OSF_ENV
 #define CWired		0x00000800	/* OSF hack only */
 #else
+#ifdef AFS_DARWIN80_ENV
+#define CDeadVnode        0x00000800
+#else
 #ifdef AFS_DARWIN_ENV
 #define CUBCinit        0x00000800
 #else
 #define CWRITE_IGN	0x00000800	/* Next OS hack only */
 #endif
 #endif
+#endif
 #define CUnique		0x00001000	/* vc's uniquifier - latest unifiquier for fid */
 #define CForeign	0x00002000	/* this is a non-afs vcache */
 #define CUnlinked	0x00010000
@@ -545,6 +550,7 @@ struct SimpleLocks {
 #define CDCLock		0x02000000	/* Vnode lock held over call to GetDownD */
 #define CBulkFetching	0x04000000	/* stats are being fetched by bulk stat */
 #define CExtendedFile	0x08000000	/* extended file via ftruncate call. */
+#define CVInit          0x10000000      /* being initialized */
 
 /* vcache vstate bits */
 #define VRevokeWait   0x1
@@ -557,13 +563,20 @@ struct SimpleLocks {
 #define vrefCount   v.v_count
 #endif /* AFS_XBSD_ENV */
 
-#if defined(AFS_LINUX24_ENV)
-#define VREFCOUNT(v)		atomic_read(&((vnode_t *) v)->v_count)
-#define VREFCOUNT_SET(v, c)	atomic_set(&((vnode_t *) v)->v_count, c)
-#define VREFCOUNT_DEC(v)	atomic_dec(&((vnode_t *) v)->v_count)
-#define VREFCOUNT_INC(v)	atomic_inc(&((vnode_t *) v)->v_count)
+#if defined(AFS_DARWIN80_ENV)
+#define VREFCOUNT_GT(v, y)    vnode_isinuse(AFSTOV(v), (y))
+#elif defined(AFS_XBSD_ENV) || defined(AFS_DARWIN_ENV)
+#define VREFCOUNT(v)          ((v)->vrefCount)
+#define VREFCOUNT_GT(v, y)    (AFSTOV(v)->v_usecount > (y))
+#elif defined(AFS_LINUX24_ENV)
+#define VREFCOUNT(v)		atomic_read(&(AFSTOV(v)->v_count))
+#define VREFCOUNT_GT(v, y)      (VREFCOUNT(v)>y)
+#define VREFCOUNT_SET(v, c)	atomic_set(&(AFSTOV(v)->v_count), c)
+#define VREFCOUNT_DEC(v)	atomic_dec(&(AFSTOV(v)->v_count))
+#define VREFCOUNT_INC(v)	atomic_inc(&(AFSTOV(v)->v_count))
 #else
 #define VREFCOUNT(v)		((v)->vrefCount)
+#define VREFCOUNT_GT(v,y)     ((v)->vrefCount > (y))
 #define VREFCOUNT_SET(v, c)	(v)->vrefCount = c;
 #define VREFCOUNT_DEC(v)	(v)->vrefCount--;
 #define VREFCOUNT_INC(v)	(v)->vrefCount++;
@@ -580,21 +593,10 @@ struct SimpleLocks {
 
 extern afs_int32 vmPageHog;	/* counter for # of vnodes which are page hogs. */
 
-/*
- * Fast map from vcache to dcache
- */
-struct vtodc {
-    struct dcache *dc;
-    afs_uint32 stamp;
-    struct osi_file *f;
-    afs_offs_t minLoc;		/* smallest offset into dc. */
-    afs_offs_t len;		/* largest offset into dc. */
-};
-
-extern afs_uint32 afs_stampValue;	/* stamp for pair's usage */
-#define	MakeStamp()	(++afs_stampValue)
-
-#if defined(AFS_XBSD_ENV) || defined(AFS_DARWIN_ENV)
+#if defined(AFS_DARWIN80_ENV)
+#define VTOAFS(v) ((struct vcache *)vnode_fsnode((v)))
+#define AFSTOV(vc) ((vc)->v)
+#elif defined(AFS_XBSD_ENV) || defined(AFS_DARWIN_ENV) || (defined(AFS_LINUX22_ENV) && !defined(STRUCT_SUPER_HAS_ALLOC_INODE))
 #define VTOAFS(v) ((struct vcache *)(v)->v_data)
 #define AFSTOV(vc) ((vc)->v)
 #else
@@ -602,24 +604,22 @@ extern afs_uint32 afs_stampValue;	/* stamp for pair's usage */
 #define AFSTOV(V) (&(V)->v)
 #endif
 
-#ifdef AFS_LINUX22_ENV
-#define ITOAFS(V) ((struct vcache*)(V))
-#define AFSTOI(V) (struct inode *)(&(V)->v)
-#endif
-
 /* INVARIANTs: (vlruq.next != NULL) == (vlruq.prev != NULL)
  *             nextfree => !vlruq.next && ! vlruq.prev
  * !(avc->nextfree) && !avc->vlruq.next => (FreeVCList == avc->nextfree)
  */
 struct vcache {
-#if defined(AFS_XBSD_ENV)||defined(AFS_DARWIN_ENV)
+#if defined(AFS_XBSD_ENV) || defined(AFS_DARWIN_ENV) || (defined(AFS_LINUX22_ENV) && !defined(STRUCT_SUPER_HAS_ALLOC_INODE))
     struct vnode *v;
 #else
     struct vnode v;		/* Has reference count in v.v_count */
 #endif
     struct afs_q vlruq;		/* lru q next and prev */
+#if !defined(AFS_LINUX22_ENV)
     struct vcache *nextfree;	/* next on free list (if free) */
+#endif
     struct vcache *hnext;	/* Hash next */
+    struct afs_q vhashq;	/* Hashed per-volume list */
     struct VenusFid fid;
     struct mstat {
 	afs_size_t Length;
@@ -629,7 +629,11 @@ struct vcache {
 	afs_uint32 Group;
 	afs_uint16 Mode;	/* XXXX Should be afs_int32 XXXX */
 	afs_uint16 LinkCount;
+#ifdef AFS_DARWIN80_ENV
+        afs_uint16 Type;
+#else
 	/* vnode type is in v.v_type */
+#endif
     } m;
     afs_rwlock_t lock;		/* The lock on the vcache contents. */
 #if	defined(AFS_SUN5_ENV)
@@ -657,7 +661,9 @@ struct vcache {
 #ifdef AFS_AIX_ENV
     int ownslock;		/* pid of owner of excl lock, else 0 - defect 3083 */
 #endif
-#ifdef AFS_DARWIN_ENV
+#ifdef AFS_DARWIN80_ENV
+    lck_mtx_t *rwlock;
+#elif defined(AFS_DARWIN_ENV)
     struct lock__bsd__ rwlock;
 #endif
 #ifdef AFS_XBSD_ENV
@@ -689,12 +695,7 @@ struct vcache {
 #if	defined(AFS_SUN5_ENV)
     afs_uint32 vstates;		/* vstate bits */
 #endif				/* defined(AFS_SUN5_ENV) */
-    struct vtodc quick;
-    afs_uint32 symhintstamp;
-    union {
-	struct vcache *symhint;
-	struct dcache *dchint;
-    } h1;
+    struct dcache *dchint;
 #ifdef AFS_LINUX22_ENV
     u_short mapcnt;		/* Number of mappings of this file. */
 #endif
@@ -722,9 +723,6 @@ struct vcache {
 #endif
 };
 
-#define afs_symhint_inval(avc)
-
-
 #define	DONT_CHECK_MODE_BITS	0
 #define	CHECK_MODE_BITS		1
 #define CMB_ALLOW_EXEC_AS_READ  2	/* For the NFS xlator */
@@ -784,6 +782,13 @@ struct vcxstat {
     afs_uint32 states;
 };
 
+struct vcxstat2 {
+    afs_int32 callerAccess;
+    afs_int32 cbExpires;
+    afs_int32 anyAccess;
+    char mvstat;
+};
+
 struct sbstruct {
     int sb_thisfile;
     int sb_default;
@@ -915,7 +920,7 @@ struct buffer {
   char lockers;
   char dirty;
   char hashIndex;
-#if AFS_USEBUFFERS
+#if defined(AFS_USEBUFFERS)
   struct buf *bufp;
 #endif
   afs_rwlock_t lock;          /* the lock for this structure */
@@ -952,7 +957,6 @@ struct dcache {
     char dflags;		/* Data flags */
     char mflags;		/* Meta flags */
     struct fcache f;		/* disk image */
-    afs_int32 stamp;		/* used with vtodc struct for hints */
 
     /*
      * Locking rules:
@@ -972,10 +976,6 @@ struct dcache {
      * Note that dcache.lock(W) gives you the right to update mflags,
      * as dcache.mflock(W) can only be held with dcache.lock(R).
      *
-     * dcache.stamp is protected by the associated vcache lock, because
-     * it's only purpose is to establish correspondence between vcache
-     * and dcache entries.
-     *
      * dcache.index, dcache.f.fid, dcache.f.chunk and dcache.f.inode are
      * write-protected by afs_xdcache and read-protected by refCount.
      * Once an entry is referenced, these values cannot change, and if
@@ -985,8 +985,6 @@ struct dcache {
      * ensuring noone else has a refCount on it).
      */
 };
-/* this is obsolete and should be removed */
-#define ihint stamp
 
 /* afs_memcache.c */
 struct memCacheEntry {
@@ -1055,6 +1053,8 @@ struct memCacheEntry {
 /* don't hash on the cell, our callback-breaking code sometimes fails to compute
     the cell correctly, and only scans one hash bucket */
 #define	VCHash(fid)	(((fid)->Fid.Volume + (fid)->Fid.Vnode) & (VCSIZE-1))
+/* Hash only on volume to speed up volume callbacks. */
+#define VCHashV(fid) ((fid)->Fid.Volume & (VCSIZE-1))
 
 extern struct dcache **afs_indexTable;	/*Pointers to in-memory dcache entries */
 extern afs_int32 *afs_indexUnique;	/*dcache entry Fid.Unique */
@@ -1064,6 +1064,7 @@ extern afs_int32 afs_cacheFiles;	/*Size of afs_indexTable */
 extern afs_int32 afs_cacheBlocks;	/*1K blocks in cache */
 extern afs_int32 afs_cacheStats;	/*Stat entries in cache */
 extern struct vcache *afs_vhashT[VCSIZE];	/*Stat cache hash table */
+extern struct afs_q afs_vhashTV[VCSIZE]; /* cache hash table on volume */
 extern afs_int32 afs_initState;	/*Initialization state */
 extern afs_int32 afs_termState;	/* Termination state */
 extern struct VenusFid afs_rootFid;	/*Root for whole file system */
@@ -1084,11 +1085,6 @@ extern struct brequest afs_brs[NBRS];	/* request structures */
  * GetVCache incantation, and could eliminate even this code from afs_UFSRead 
  * by making intentionally invalidating quick.stamp in the various callbacks
  * expiration/breaking code */
-#ifdef AFS_LINUX20_ENV
-#define afs_VerifyVCache(avc, areq)  \
-  (((avc)->states & CStatd) ? (vcache2inode(avc), 0) : \
-   afs_VerifyVCache2((avc),areq))
-#else
 #ifdef AFS_DARWIN_ENV
 #define afs_VerifyVCache(avc, areq)  \
   (((avc)->states & CStatd) ? (osi_VM_Setup(avc, 0), 0) : \
@@ -1097,10 +1093,11 @@ extern struct brequest afs_brs[NBRS];	/* request structures */
 #define afs_VerifyVCache(avc, areq)  \
   (((avc)->states & CStatd) ? 0 : afs_VerifyVCache2((avc),areq))
 #endif
-#endif
 
 #define DO_STATS 1		/* bits used by FindVCache */
 #define DO_VLRU 2
+#define IS_SLOCK 4
+#define IS_WLOCK 8
 
 /* values for flag param of afs_CheckVolumeNames */
 #define AFS_VOLCHECK_EXPIRED	0x1	/* volumes whose callbacks have expired */
@@ -1139,11 +1136,15 @@ extern struct brequest afs_brs[NBRS];	/* request structures */
 #define CM_CACHESIZEDRAINEDPCT	95	/* wakeup processes when down to here. */
 #define CM_WAITFORDRAINPCT	98	/* sleep if cache is this full. */
 
+/* when afs_cacheBlocks is large, settle for slightly decreased precision */
+#define PERCENT(p, v) \
+    ((afs_cacheBlocks & 0xffe00000) ? ((v) / 100 * (p)) : ((p) * (v) / 100))
+
 #define afs_CacheIsTooFull() \
     (afs_blocksUsed - afs_blocksDiscarded > \
-	(CM_DCACHECOUNTFREEPCT*afs_cacheBlocks)/100 || \
+	PERCENT(CM_DCACHECOUNTFREEPCT, afs_cacheBlocks) || \
      afs_freeDCCount - afs_discardDCCount < \
-	((100-CM_DCACHECOUNTFREEPCT)*afs_cacheFiles)/100)
+	PERCENT(100 - CM_DCACHECOUNTFREEPCT, afs_cacheFiles))
 
 /* Handy max length of a numeric string. */
 #define	CVBS	12		/* max afs_int32 is 2^32 ~ 4*10^9, +1 for NULL, +luck */
