@@ -75,7 +75,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_cbqueue.c,v 1.9 2003/07/15 23:14:11 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/afs_cbqueue.c,v 1.9.2.4 2006/03/02 06:44:05 shadow Exp $");
 
 #include "afs/sysincludes.h"	/*Standard vendor system headers */
 #include "afsincludes.h"	/*AFS-based standard headers */
@@ -141,9 +141,7 @@ afs_DequeueCallback(struct vcache *avc)
     debugvc = avc;
     if (avc->callsort.prev) {
 	QRemove(&(avc->callsort));
-	avc->callsort.prev = avc->callsort.next = NULL;
     } else;			/* must have got dequeued in a race */
-    afs_symhint_inval(avc);
 
     return;
 }				/* afs_DequeueCallback */
@@ -221,13 +219,12 @@ afs_CheckCallbacks(unsigned int secs)
 			    /* What about locking xvcache or vrefcount++ or
 			     * write locking tvc? */
 			    QRemove(tq);
-			    tq->prev = tq->next = NULL;
 			    tvc->states &= ~(CStatd | CMValid | CUnique);
-			    if ((tvc->fid.Fid.Vnode & 1)
-				|| (vType(tvc) == VDIR))
+                            if (!(tvc->states & (CVInit|CVFlushed)) &&
+                                (tvc->fid.Fid.Vnode & 1 ||
+                                 (vType(tvc) == VDIR)))
 				osi_dnlc_purgedp(tvc);
-			    tvc->quick.stamp = 0;
-			    tvc->h1.dchint = NULL;	/*invalidate em */
+			    tvc->dchint = NULL;	/*invalidate em */
 			    afs_ResetVolumeInfo(tvp);
 			    break;
 			}
@@ -239,9 +236,9 @@ afs_CheckCallbacks(unsigned int secs)
 		 * What about locking xvcache or vrefcount++ or write locking tvc?
 		 */
 		QRemove(tq);
-		tq->prev = tq->next = NULL;
 		tvc->states &= ~(CStatd | CMValid | CUnique);
-		if ((tvc->fid.Fid.Vnode & 1) || (vType(tvc) == VDIR))
+                if (!(tvc->states & (CVInit|CVFlushed)) &&
+                    (tvc->fid.Fid.Vnode & 1 || (vType(tvc) == VDIR)))
 		    osi_dnlc_purgedp(tvc);
 	    }
 	}
@@ -309,12 +306,13 @@ afs_FlushCBs(void)
     for (i = 0; i < VCSIZE; i++)	/* reset all the vnodes */
 	for (tvc = afs_vhashT[i]; tvc; tvc = tvc->hnext) {
 	    tvc->callback = 0;
-	    tvc->quick.stamp = 0;
-	    tvc->h1.dchint = NULL;	/* invalidate hints */
+	    tvc->dchint = NULL;	/* invalidate hints */
 	    tvc->states &= ~(CStatd);
-	    if ((tvc->fid.Fid.Vnode & 1) || (vType(tvc) == VDIR))
+	    if (QPrev(&(tvc->callsort)))
+		QRemove(&(tvc->callsort));
+	    if (!(tvc->states & (CVInit|CVFlushed)) &&
+                ((tvc->fid.Fid.Vnode & 1) || (vType(tvc) == VDIR)))
 		osi_dnlc_purgedp(tvc);
-	    tvc->callsort.prev = tvc->callsort.next = NULL;
 	}
 
     afs_InitCBQueue(0);
@@ -339,10 +337,10 @@ afs_FlushServerCBs(struct server *srvp)
 	for (tvc = afs_vhashT[i]; tvc; tvc = tvc->hnext) {
 	    if (tvc->callback == srvp) {
 		tvc->callback = 0;
-		tvc->quick.stamp = 0;
-		tvc->h1.dchint = NULL;	/* invalidate hints */
+		tvc->dchint = NULL;	/* invalidate hints */
 		tvc->states &= ~(CStatd);
-		if ((tvc->fid.Fid.Vnode & 1) || (vType(tvc) == VDIR)) {
+		if (!(tvc->states & (CVInit|CVFlushed)) &&
+                    ((tvc->fid.Fid.Vnode & 1) || (vType(tvc) == VDIR))) {
 		    osi_dnlc_purgedp(tvc);
 		}
 		afs_DequeueCallback(tvc);
