@@ -26,17 +26,17 @@
  */
 
 #include <afsconfig.h>
-#include "../afs/param.h"
+#include "afs/param.h"
 
-#include "../afs/stds.h"
-#include "../afs/sysincludes.h" /* Standard vendor system headers */
-#include "../afs/afsincludes.h"
-#include "../afs/afs_osi.h"
-#include "../afsint/afsint.h"
-#include "../afs/lock.h"
+#include "afs/stds.h"
+#include "afs/sysincludes.h"	/* Standard vendor system headers */
+#include "afsincludes.h"
+#include "afs/afs_osi.h"
+#include "afsint.h"
+#include "afs/lock.h"
 
-#include "../afs/prs_fs.h"
-#include "../afs/dir.h"
+#include "afs/prs_fs.h"
+#include "afs/dir.h"
 
 #define AFS_DYNROOT_CELLNAME	"dynroot"
 #define AFS_DYNROOT_VOLUME	1
@@ -91,22 +91,21 @@ static struct afs_dynSymlink *afs_dynSymlinkBase = NULL;
 static int afs_dynSymlinkIndex = 0;
 /* End of variables protected by afs_dynSymlinkLock */
 
-extern afs_int32 afs_cellindex;
-extern afs_rwlock_t afs_xvcache;
-
 /*
  * Set up a cell for dynroot if it's not there yet.
  */
-static int afs_dynrootCellInit()
+static int
+afs_dynrootCellInit()
 {
     if (afs_dynrootEnable && !afs_dynrootCell) {
 	afs_int32 cellHosts[MAXCELLHOSTS];
 	struct cell *tc;
 	int code;
- 
+
 	memset(cellHosts, 0, sizeof(cellHosts));
-	code = afs_NewCell(AFS_DYNROOT_CELLNAME, cellHosts, CNoSUID | CNoAFSDB,
-			   NULL, 0, 0, 0);
+	code =
+	    afs_NewCell(AFS_DYNROOT_CELLNAME, cellHosts, CNoSUID | CNoAFSDB,
+			NULL, 0, 0, 0);
 	if (code)
 	    return code;
 	tc = afs_GetCellByName(AFS_DYNROOT_CELLNAME, READ_LOCK);
@@ -115,6 +114,7 @@ static int afs_dynrootCellInit()
 	afs_dynrootCell = tc->cellNum;
 	afs_PutCell(tc, READ_LOCK);
     }
+
     return 0;
 }
 
@@ -124,23 +124,21 @@ static int afs_dynrootCellInit()
 int
 afs_IsDynrootFid(struct VenusFid *fid)
 {
-    return
-	(afs_dynrootEnable &&
-	 fid->Cell       == afs_dynrootCell   &&
-	 fid->Fid.Volume == AFS_DYNROOT_VOLUME &&
-	 fid->Fid.Vnode  == AFS_DYNROOT_VNODE  &&
-	 fid->Fid.Unique == AFS_DYNROOT_UNIQUE);
+    return (afs_dynrootEnable && fid->Cell == afs_dynrootCell
+	    && fid->Fid.Volume == AFS_DYNROOT_VOLUME
+	    && fid->Fid.Vnode == AFS_DYNROOT_VNODE
+	    && fid->Fid.Unique == AFS_DYNROOT_UNIQUE);
 }
 
 /*
  * Obtain the magic dynroot volume Fid.
  */
 void
-afs_GetDynrootFid(struct VenusFid *fid) 
+afs_GetDynrootFid(struct VenusFid *fid)
 {
-    fid->Cell       = afs_dynrootCell;
+    fid->Cell = afs_dynrootCell;
     fid->Fid.Volume = AFS_DYNROOT_VOLUME;
-    fid->Fid.Vnode  = AFS_DYNROOT_VNODE;
+    fid->Fid.Vnode = AFS_DYNROOT_VNODE;
     fid->Fid.Unique = AFS_DYNROOT_UNIQUE;
 }
 
@@ -148,8 +146,7 @@ afs_GetDynrootFid(struct VenusFid *fid)
  * Returns non-zero iff avc is a pointer to the dynroot /afs vnode.
  */
 int
-afs_IsDynroot(avc)
-    struct vcache *avc;
+afs_IsDynroot(struct vcache *avc)
 {
     return afs_IsDynrootFid(&avc->fid);
 }
@@ -159,7 +156,8 @@ afs_IsDynroot(avc)
  * appropriately so that the given file name can be appended.  Used for
  * computing the size of a directory.
  */
-static void afs_dynroot_computeDirEnt(char *name, int *curPageP, int *curChunkP)
+static void
+afs_dynroot_computeDirEnt(char *name, int *curPageP, int *curChunkP)
 {
     int esize;
 
@@ -177,14 +175,10 @@ static void afs_dynroot_computeDirEnt(char *name, int *curPageP, int *curChunkP)
  * the necessary entry.
  */
 static void
-afs_dynroot_addDirEnt(dirHeader, curPageP, curChunkP, name, vnode)
-    struct DirHeader *dirHeader;
-    int *curPageP;
-    int *curChunkP;
-    char *name;
-    int vnode;
+afs_dynroot_addDirEnt(struct DirHeader *dirHeader, int *curPageP,
+		      int *curChunkP, char *name, int vnode)
 {
-    char *dirBase = (char *) dirHeader;
+    char *dirBase = (char *)dirHeader;
     struct PageHeader *pageHeader;
     struct DirEntry *dirEntry;
     int sizeOfEntry, i, t1, t2;
@@ -202,23 +196,23 @@ afs_dynroot_addDirEnt(dirHeader, curPageP, curChunkP, name, vnode)
 	didNewPage = 1;
     }
 
-    pageHeader = (struct PageHeader *) (dirBase + curPage * AFS_PAGESIZE);
+    pageHeader = (struct PageHeader *)(dirBase + curPage * AFS_PAGESIZE);
     if (didNewPage) {
 	pageHeader->pgcount = 0;
 	pageHeader->tag = htons(1234);
 	pageHeader->freecount = 0;
 	pageHeader->freebitmap[0] = 0x01;
-	for (i = 1; i < EPP/8; i++)
+	for (i = 1; i < EPP / 8; i++)
 	    pageHeader->freebitmap[i] = 0;
 
 	dirHeader->alloMap[curPage] = EPP - 1;
     }
 
-    dirEntry = (struct DirEntry *) (pageHeader + curChunk);
-    dirEntry->flag        = 1;
-    dirEntry->length      = 0;
-    dirEntry->next        = 0;
-    dirEntry->fid.vnode   = htonl(vnode);
+    dirEntry = (struct DirEntry *)(pageHeader + curChunk);
+    dirEntry->flag = 1;
+    dirEntry->length = 0;
+    dirEntry->next = 0;
+    dirEntry->fid.vnode = htonl(vnode);
     dirEntry->fid.vunique = htonl(1);
     strcpy(dirEntry->name, name);
 
@@ -246,25 +240,26 @@ afs_dynroot_addDirEnt(dirHeader, curPageP, curChunkP, name, vnode)
  * Invalidate the /afs vnode for dynroot; called when the underlying
  * directory has changed and needs to be re-read.
  */
-void afs_DynrootInvalidate(void)
+void
+afs_DynrootInvalidate(void)
 {
     afs_int32 retry;
     struct vcache *tvc;
     struct VenusFid tfid;
- 
+
     if (!afs_dynrootEnable)
 	return;
- 
+
     ObtainWriteLock(&afs_dynrootDirLock, 687);
     afs_dynrootVersion++;
     afs_dynrootVersionHigh = osi_Time();
     ReleaseWriteLock(&afs_dynrootDirLock);
- 
+
     afs_GetDynrootFid(&tfid);
     do {
 	retry = 0;
 	ObtainReadLock(&afs_xvcache);
-	tvc = afs_FindVCache(&tfid, 0, 0, &retry, 0);
+	tvc = afs_FindVCache(&tfid, &retry, 0);
 	ReleaseReadLock(&afs_xvcache);
     } while (retry);
     if (tvc) {
@@ -279,17 +274,17 @@ void afs_DynrootInvalidate(void)
  * cells.  Useful when the list of cells has changed due to
  * an AFSDB lookup, for instance.
  */
-static void afs_RebuildDynroot(void)
+static void
+afs_RebuildDynroot(void)
 {
     int cellidx, maxcellidx, i;
     int aliasidx, maxaliasidx;
     struct cell *c;
     struct cell_alias *ca;
     int curChunk, curPage;
-    int dirSize, sizeOfCurEntry, dotLen;
+    int dirSize, dotLen;
     char *newDir, *dotCell;
     struct DirHeader *dirHeader;
-    struct DirEntry *dirEntry;
     int linkCount = 0;
     struct afs_dynSymlink *ts;
     int newVersion;
@@ -307,55 +302,40 @@ static void afs_RebuildDynroot(void)
     /* Reserve space for "." and ".." */
     curChunk += 2;
 
-    for (cellidx = 0; ; cellidx++) {
+    for (cellidx = 0;; cellidx++) {
 	c = afs_GetCellByIndex(cellidx, READ_LOCK);
-	if (!c) break;
-	if (c->cellNum == afs_dynrootCell) continue;
-
-	sizeOfCurEntry = afs_dir_NameBlobs(c->cellName);
-	if (curChunk + sizeOfCurEntry > EPP) {
-	    curPage++;
-	    curChunk = 1;
-	}
-	curChunk += sizeOfCurEntry;
+	if (!c)
+	    break;
+	if (c->cellNum == afs_dynrootCell)
+	    continue;
 
 	dotLen = strlen(c->cellName) + 2;
 	dotCell = afs_osi_Alloc(dotLen);
 	strcpy(dotCell, ".");
-	strcat(dotCell, c->cellName);
-	sizeOfCurEntry = afs_dir_NameBlobs(dotCell);
-	if (curChunk + sizeOfCurEntry > EPP) {
-	    curPage++;
-	    curChunk = 1;
-	}
-	curChunk += sizeOfCurEntry;
+	afs_strcat(dotCell, c->cellName);
+
+	afs_dynroot_computeDirEnt(c->cellName, &curPage, &curChunk);
+	afs_dynroot_computeDirEnt(dotCell, &curPage, &curChunk);
 
 	afs_osi_Free(dotCell, dotLen);
 	afs_PutCell(c, READ_LOCK);
     }
     maxcellidx = cellidx;
 
-    for (aliasidx = 0; ; aliasidx++) {
+    for (aliasidx = 0;; aliasidx++) {
 	ca = afs_GetCellAlias(aliasidx);
-	if (!ca) break;
+	if (!ca)
+	    break;
 
-	sizeOfCurEntry = afs_dir_NameBlobs(ca->alias);
-	if (curChunk + sizeOfCurEntry > EPP) {
-	    curPage++;
-	    curChunk = 1;
-	}
-	curChunk += sizeOfCurEntry;
-
-	dotCell = afs_osi_Alloc(strlen(ca->alias) + 2);
+	dotLen = strlen(ca->alias) + 2;
+	dotCell = afs_osi_Alloc(dotLen);
 	strcpy(dotCell, ".");
-	strcat(dotCell, ca->alias);
-	sizeOfCurEntry = afs_dir_NameBlobs(dotCell);
-	if (curChunk + sizeOfCurEntry > EPP) {
-	    curPage++;
-	    curChunk = 1;
-	}
-	curChunk += sizeOfCurEntry;
+	afs_strcat(dotCell, ca->alias);
 
+	afs_dynroot_computeDirEnt(ca->alias, &curPage, &curChunk);
+	afs_dynroot_computeDirEnt(dotCell, &curPage, &curChunk);
+
+	afs_osi_Free(dotCell, dotLen);
 	afs_PutCellAlias(ca);
     }
     maxaliasidx = aliasidx;
@@ -363,12 +343,7 @@ static void afs_RebuildDynroot(void)
     ObtainReadLock(&afs_dynSymlinkLock);
     ts = afs_dynSymlinkBase;
     while (ts) {
-	sizeOfCurEntry = afs_dir_NameBlobs(ts->name);
-	if (curChunk + sizeOfCurEntry > EPP) {
-	    curPage++;
-	    curChunk = 1;
-	}
-	curChunk += sizeOfCurEntry;
+	afs_dynroot_computeDirEnt(ts->name, &curPage, &curChunk);
 	ts = ts->next;
     }
 
@@ -380,7 +355,7 @@ static void afs_RebuildDynroot(void)
      */
     curChunk = 13;
     curPage = 0;
-    dirHeader = (struct DirHeader *) newDir;
+    dirHeader = (struct DirHeader *)newDir;
 
     dirHeader->header.pgcount = 0;
     dirHeader->header.tag = htons(1234);
@@ -388,7 +363,7 @@ static void afs_RebuildDynroot(void)
 
     dirHeader->header.freebitmap[0] = 0xff;
     dirHeader->header.freebitmap[1] = 0x1f;
-    for (i = 2; i < EPP/8; i++)
+    for (i = 2; i < EPP / 8; i++)
 	dirHeader->header.freebitmap[i] = 0;
     dirHeader->alloMap[0] = EPP - DHE - 1;
     for (i = 1; i < MAXPAGES; i++)
@@ -403,54 +378,58 @@ static void afs_RebuildDynroot(void)
 
     for (cellidx = 0; cellidx < maxcellidx; cellidx++) {
 	c = afs_GetCellByIndex(cellidx, READ_LOCK);
-	if (!c) continue;
-	if (c->cellNum == afs_dynrootCell) continue;
+	if (!c)
+	    continue;
+	if (c->cellNum == afs_dynrootCell)
+	    continue;
 
 	dotLen = strlen(c->cellName) + 2;
 	dotCell = afs_osi_Alloc(dotLen);
 	strcpy(dotCell, ".");
-	strcat(dotCell, c->cellName);
-	afs_dynroot_addDirEnt(dirHeader, &curPage, &curChunk,
-			      c->cellName, VNUM_FROM_CIDX_RW(cellidx, 0));
-	afs_dynroot_addDirEnt(dirHeader, &curPage, &curChunk,
-			      dotCell, VNUM_FROM_CIDX_RW(cellidx, 1));
+	afs_strcat(dotCell, c->cellName);
+	afs_dynroot_addDirEnt(dirHeader, &curPage, &curChunk, c->cellName,
+			      VNUM_FROM_CIDX_RW(cellidx, 0));
+	afs_dynroot_addDirEnt(dirHeader, &curPage, &curChunk, dotCell,
+			      VNUM_FROM_CIDX_RW(cellidx, 1));
+	afs_osi_Free(dotCell, dotLen);
 
 	linkCount += 2;
-
-	afs_osi_Free(dotCell, dotLen);
 	afs_PutCell(c, READ_LOCK);
     }
 
     for (aliasidx = 0; aliasidx < maxaliasidx; aliasidx++) {
 	ca = afs_GetCellAlias(aliasidx);
-	if (!ca) continue;
-	
-	dotCell = afs_osi_Alloc(strlen(ca->alias) + 2);
+	if (!ca)
+	    continue;
+
+	dotLen = strlen(ca->alias) + 2;
+	dotCell = afs_osi_Alloc(dotLen);
 	strcpy(dotCell, ".");
-	strcat(dotCell, ca->alias);
-	afs_dynroot_addDirEnt(dirHeader, &curPage, &curChunk,
-			      ca->alias, VNUM_FROM_CAIDX_RW(aliasidx, 0));
-	afs_dynroot_addDirEnt(dirHeader, &curPage, &curChunk,
-			      dotCell, VNUM_FROM_CAIDX_RW(aliasidx, 1));
+	afs_strcat(dotCell, ca->alias);
+	afs_dynroot_addDirEnt(dirHeader, &curPage, &curChunk, ca->alias,
+			      VNUM_FROM_CAIDX_RW(aliasidx, 0));
+	afs_dynroot_addDirEnt(dirHeader, &curPage, &curChunk, dotCell,
+			      VNUM_FROM_CAIDX_RW(aliasidx, 1));
+	afs_osi_Free(dotCell, dotLen);
 	afs_PutCellAlias(ca);
     }
-    
+
     ts = afs_dynSymlinkBase;
     while (ts) {
 	int vnum = VNUM_FROM_TYPEID(VN_TYPE_SYMLINK, ts->index);
-	afs_dynroot_addDirEnt(dirHeader, &curPage, &curChunk,
-			      ts->name, vnum);
+	afs_dynroot_addDirEnt(dirHeader, &curPage, &curChunk, ts->name, vnum);
 	ts = ts->next;
     }
 
     ReleaseReadLock(&afs_dynSymlinkLock);
 
     ObtainWriteLock(&afs_dynrootDirLock, 549);
-    if (afs_dynrootDir) afs_osi_Free(afs_dynrootDir, afs_dynrootDirLen);
+    if (afs_dynrootDir)
+	afs_osi_Free(afs_dynrootDir, afs_dynrootDirLen);
     afs_dynrootDir = newDir;
     afs_dynrootDirLen = dirSize;
     afs_dynrootDirLinkcnt = linkCount;
-    afs_dynrootVersion = newVersion;
+    afs_dynrootDirVersion = newVersion;
     ReleaseWriteLock(&afs_dynrootDirLock);
 }
 
@@ -458,8 +437,9 @@ static void afs_RebuildDynroot(void)
  * Returns a pointer to the base of the dynroot directory in memory,
  * length thereof, and a FetchStatus.
  */
-void afs_GetDynroot(char **dynrootDir, int *dynrootLen, 
-		    struct AFSFetchStatus *status)
+void
+afs_GetDynroot(char **dynrootDir, int *dynrootLen,
+	       struct AFSFetchStatus *status)
 {
     ObtainReadLock(&afs_dynrootDirLock);
     if (!afs_dynrootDir || afs_dynrootDirVersion != afs_dynrootVersion) {
@@ -468,20 +448,22 @@ void afs_GetDynroot(char **dynrootDir, int *dynrootLen,
 	ObtainReadLock(&afs_dynrootDirLock);
     }
 
-    if (dynrootDir) *dynrootDir = afs_dynrootDir;
-    if (dynrootLen) *dynrootLen = afs_dynrootDirLen;
+    if (dynrootDir)
+	*dynrootDir = afs_dynrootDir;
+    if (dynrootLen)
+	*dynrootLen = afs_dynrootDirLen;
 
     if (status) {
 	memset(status, 0, sizeof(struct AFSFetchStatus));
-	status->FileType        = Directory;
-	status->LinkCount       = afs_dynrootDirLinkcnt;
-	status->Length          = afs_dynrootDirLen;
-	status->DataVersion     = afs_dynrootVersion;
-	status->CallerAccess    = PRSFS_LOOKUP | PRSFS_READ;
+	status->FileType = Directory;
+	status->LinkCount = afs_dynrootDirLinkcnt;
+	status->Length = afs_dynrootDirLen;
+	status->DataVersion = afs_dynrootVersion;
+	status->CallerAccess = PRSFS_LOOKUP | PRSFS_READ;
 	status->AnonymousAccess = PRSFS_LOOKUP | PRSFS_READ;
-	status->UnixModeBits    = 0755;
-	status->ParentVnode     = 1;
-	status->ParentUnique    = 1;
+	status->UnixModeBits = 0755;
+	status->ParentVnode = 1;
+	status->ParentUnique = 1;
 	status->dataVersionHigh = afs_dynrootVersionHigh;
     }
 }
@@ -490,7 +472,7 @@ void afs_GetDynroot(char **dynrootDir, int *dynrootLen,
  * Puts back the dynroot read lock.
  */
 void
-afs_PutDynroot()
+afs_PutDynroot(void)
 {
     ReleaseReadLock(&afs_dynrootDirLock);
 }
@@ -501,11 +483,10 @@ afs_PutDynroot()
  * FetchStatus will be filled in.
  */
 int
-afs_DynrootNewVnode(avc, status)
-    struct vcache *avc;
-    struct AFSFetchStatus *status;
+afs_DynrootNewVnode(struct vcache *avc, struct AFSFetchStatus *status)
 {
-    if (!afs_dynrootEnable) return 0;
+    if (!afs_dynrootEnable)
+	return 0;
 
     if (afs_IsDynroot(avc)) {
 	afs_GetDynroot(0, 0, status);
@@ -516,8 +497,8 @@ afs_DynrootNewVnode(avc, status)
     /*
      * Check if this is an entry under /afs, e.g. /afs/cellname.
      */
-    if (avc->fid.Cell       == afs_dynrootCell &&
-	avc->fid.Fid.Volume == AFS_DYNROOT_VOLUME) {
+    if (avc->fid.Cell == afs_dynrootCell
+	&& avc->fid.Fid.Volume == AFS_DYNROOT_VOLUME) {
 
 	struct cell *c;
 	struct cell_alias *ca;
@@ -525,13 +506,13 @@ afs_DynrootNewVnode(avc, status)
 
 	memset(status, 0, sizeof(struct AFSFetchStatus));
 
-	status->FileType        = SymbolicLink;
-	status->LinkCount       = 1;
-	status->DataVersion     = 1;
-	status->CallerAccess    = PRSFS_LOOKUP | PRSFS_READ;
+	status->FileType = SymbolicLink;
+	status->LinkCount = 1;
+	status->DataVersion = 1;
+	status->CallerAccess = PRSFS_LOOKUP | PRSFS_READ;
 	status->AnonymousAccess = PRSFS_LOOKUP | PRSFS_READ;
-	status->ParentVnode     = 1;
-	status->ParentUnique    = 1;
+	status->ParentVnode = 1;
+	status->ParentUnique = 1;
 
 	if (VNUM_TO_VNTYPE(avc->fid.Fid.Vnode) == VN_TYPE_SYMLINK) {
 	    struct afs_dynSymlink *ts;
@@ -540,7 +521,8 @@ afs_DynrootNewVnode(avc, status)
 	    ObtainReadLock(&afs_dynSymlinkLock);
 	    ts = afs_dynSymlinkBase;
 	    while (ts) {
-		if (ts->index == index) break;
+		if (ts->index == index)
+		    break;
 		ts = ts->next;
 	    }
 
@@ -549,7 +531,7 @@ afs_DynrootNewVnode(avc, status)
 		avc->linkData = afs_osi_Alloc(linklen + 1);
 		strcpy(avc->linkData, ts->target);
 
-		status->Length       = linklen;
+		status->Length = linklen;
 		status->UnixModeBits = 0755;
 	    }
 	    ReleaseReadLock(&afs_dynSymlinkLock);
@@ -557,8 +539,8 @@ afs_DynrootNewVnode(avc, status)
 	    return ts ? 1 : 0;
 	}
 
-	if (VNUM_TO_VNTYPE(avc->fid.Fid.Vnode) != VN_TYPE_CELL &&
-	    VNUM_TO_VNTYPE(avc->fid.Fid.Vnode) != VN_TYPE_ALIAS) {
+	if (VNUM_TO_VNTYPE(avc->fid.Fid.Vnode) != VN_TYPE_CELL
+	    && VNUM_TO_VNTYPE(avc->fid.Fid.Vnode) != VN_TYPE_ALIAS) {
 	    afs_warn("dynroot vnode inconsistency, unknown VNTYPE %d\n",
 		     VNUM_TO_VNTYPE(avc->fid.Fid.Vnode));
 	    return 0;
@@ -592,7 +574,7 @@ afs_DynrootNewVnode(avc, status)
 		linklen = rw + namelen;
 		avc->linkData = afs_osi_Alloc(linklen + 1);
 		strcpy(avc->linkData, rw ? "." : "");
-		strcat(avc->linkData, realName);
+		afs_strcat(avc->linkData, realName);
 	    }
 
 	    status->UnixModeBits = 0755;
@@ -612,8 +594,8 @@ afs_DynrootNewVnode(avc, status)
 	    linklen = 1 + namelen + 10;
 	    avc->linkData = afs_osi_Alloc(linklen + 1);
 	    strcpy(avc->linkData, rw ? "%" : "#");
-	    strcat(avc->linkData, c->cellName);
-	    strcat(avc->linkData, ":root.cell");
+	    afs_strcat(avc->linkData, c->cellName);
+	    afs_strcat(avc->linkData, ":root.cell");
 
 	    status->UnixModeBits = 0644;
 	    afs_PutCell(c, READ_LOCK);
@@ -630,9 +612,10 @@ afs_DynrootNewVnode(avc, status)
  * Enable or disable dynroot.  Returns 0 if successful.
  */
 int
-afs_SetDynrootEnable(enable)
-    int enable;
+afs_SetDynrootEnable(int enable)
 {
+    RWLOCK_INIT(&afs_dynrootDirLock, "afs_dynrootDirLock");
+    RWLOCK_INIT(&afs_dynSymlinkLock, "afs_dynSymlinkLock");
     afs_dynrootEnable = enable;
     return afs_dynrootCellInit();
 }
@@ -641,7 +624,7 @@ afs_SetDynrootEnable(enable)
  * Check if dynroot support is enabled.
  */
 int
-afs_GetDynrootEnable()
+afs_GetDynrootEnable(void)
 {
     return afs_dynrootEnable;
 }
@@ -650,8 +633,7 @@ afs_GetDynrootEnable()
  * Remove a temporary symlink entry from /afs.
  */
 int
-afs_DynrootVOPRemove(struct vcache *avc, struct AFS_UCRED *acred,
-		     char *aname)
+afs_DynrootVOPRemove(struct vcache *avc, struct AFS_UCRED *acred, char *aname)
 {
     struct afs_dynSymlink **tpps;
     struct afs_dynSymlink *tps;
@@ -683,7 +665,7 @@ afs_DynrootVOPRemove(struct vcache *avc, struct AFS_UCRED *acred,
 
     if (afs_CellOrAliasExists(aname))
 	return EROFS;
-    else 
+    else
 	return ENOENT;
 }
 
@@ -691,19 +673,15 @@ afs_DynrootVOPRemove(struct vcache *avc, struct AFS_UCRED *acred,
  * Create a temporary symlink entry in /afs.
  */
 int
-afs_DynrootVOPSymlink(avc, acred, aname, atargetName)
-    struct vcache *avc;
-    struct AFS_UCRED *acred;
-    char *aname;
-    char *atargetName;
+afs_DynrootVOPSymlink(struct vcache *avc, struct AFS_UCRED *acred,
+		      char *aname, char *atargetName)
 {
     struct afs_dynSymlink *tps;
 
     if (acred->cr_uid)
 	return EPERM;
-
     if (afs_CellOrAliasExists(aname))
-        return EEXIST;
+	return EEXIST;
 
     /* Check if it's already a symlink */
     ObtainWriteLock(&afs_dynSymlinkLock, 91);
