@@ -11,14 +11,15 @@
 
 #ifndef lint
 static char rcsid_send_to_kdc_c[] =
-"$Id: krb_util.c,v 1.1.2.1 2004/12/07 05:51:24 shadow Exp $";
+"$Id: krb_util.c,v 1.1.2.4 2005/07/15 16:11:24 rra Exp $";
 #endif /* lint */
 
 #if 0
 #include <kerberosIV/mit-copyright.h>
 #endif
+#include <afs/stds.h>
+#include "aklog.h"
 #include <krb5.h>
-#include <kerberosIV/krb.h> 
 
 #ifndef MAX_HSTNM
 #define MAX_HSTNM 100
@@ -35,13 +36,12 @@ static char rcsid_send_to_kdc_c[] =
 
 #endif /* WINDOWS */
 
+#include <string.h>
+
 #define S_AD_SZ sizeof(struct sockaddr_in)
 
-char *afs_realm_of_cell(context, cellconfig)
-    krb5_context context;
-    struct afsconf_cell *cellconfig;
+char *afs_realm_of_cell(krb5_context context, struct afsconf_cell *cellconfig)
 {
-    char krbhst[MAX_HSTNM];
     static char krbrlm[REALM_SZ+1];
 	char **hrealms = 0;
 	krb5_error_code retval;
