@@ -9,8 +9,12 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/bucoord/dlq.c,v 1.1.1.4 2001/07/14 22:20:51 hartmans Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/bucoord/dlq.c,v 1.9 2003/12/12 23:29:49 shadow Exp $");
 
 #include <afs/bubasics.h>
 
@@ -30,30 +34,30 @@ RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/bucoord
  */
 
 dlqEmpty(headptr)
-     dlqlinkP	headptr;
+     dlqlinkP headptr;
 {
     DLQ_ASSERT_HEAD(headptr);
-    if ( headptr->dlq_next == headptr )
-	return(1);
-    return(0);
+    if (headptr->dlq_next == headptr)
+	return (1);
+    return (0);
 }
 
 dlqInit(headptr)
-     dlqlinkP	headptr;
+     dlqlinkP headptr;
 {
     headptr->dlq_next = headptr;
     headptr->dlq_prev = headptr;
     headptr->dlq_type = DLQ_HEAD;
-    headptr->dlq_structPtr = (char *)0;
-    return(0);
+    headptr->dlq_structPtr = NULL;
+    return (0);
 }
 
 /* dlqLinkf
  *	link item to front of chain
  */
 dlqLinkf(headptr, entryptr)
-     dlqlinkP	headptr;
-     dlqlinkP	entryptr;
+     dlqlinkP headptr;
+     dlqlinkP entryptr;
 {
     DLQ_ASSERT_HEAD(headptr);
     /* link in as first item in chain */
@@ -61,16 +65,16 @@ dlqLinkf(headptr, entryptr)
     headptr->dlq_next->dlq_prev = entryptr;
     entryptr->dlq_prev = headptr;
     headptr->dlq_next = entryptr;
-    return(0);
-}	
+    return (0);
+}
 
 /* dlqLinkb
  *	link item to end of chain
  */
 
 dlqLinkb(headptr, entryptr)
-     dlqlinkP	headptr;
-     dlqlinkP	entryptr;
+     dlqlinkP headptr;
+     dlqlinkP entryptr;
 {
     DLQ_ASSERT_HEAD(headptr);
     entryptr->dlq_next = headptr;
@@ -78,24 +82,25 @@ dlqLinkb(headptr, entryptr)
 
     headptr->dlq_prev = entryptr;
     entryptr->dlq_prev->dlq_next = entryptr;
-    return(0);
+    return (0);
 }
 
 /* dlqMoveb
  *	move all the items on the fromptr and append to the toptr's list
  */
 
+void
 dlqMoveb(fromptr, toptr)
-     dlqlinkP	fromptr;
-     dlqlinkP	toptr;
+     dlqlinkP fromptr;
+     dlqlinkP toptr;
 {
-    dlqlinkP	tailptr;
+    dlqlinkP tailptr;
 
     DLQ_ASSERT_HEAD(fromptr);
     DLQ_ASSERT_HEAD(toptr);
 
-    if ( dlqEmpty(fromptr) )
-	return(0);
+    if (dlqEmpty(fromptr))
+	return;
 
     tailptr = toptr->dlq_prev;
 
@@ -110,6 +115,7 @@ dlqMoveb(fromptr, toptr)
 
     fromptr->dlq_next = fromptr;
     fromptr->dlq_prev = fromptr;
+    return;
 }
 
 /* dlqUnlinkb
@@ -117,22 +123,22 @@ dlqMoveb(fromptr, toptr)
  */
 
 dlqlinkP
-dlqUnlinkb(headptr) 
-     dlqlinkP	headptr;
+dlqUnlinkb(headptr)
+     dlqlinkP headptr;
 {
-    dlqlinkP	ptr;
+    dlqlinkP ptr;
     DLQ_ASSERT_HEAD(headptr);
 
-    if ( dlqEmpty(headptr) )
-	return(0);
+    if (dlqEmpty(headptr))
+	return (0);
 
     ptr = headptr->dlq_prev;
     ptr->dlq_prev->dlq_next = headptr;
     headptr->dlq_prev = ptr->dlq_prev;
-    
+
     ptr->dlq_next = ptr;
     ptr->dlq_prev = ptr;
-    return(ptr);
+    return (ptr);
 }
 
 /* dlqUnlinkf
@@ -141,13 +147,13 @@ dlqUnlinkb(headptr)
 
 dlqlinkP
 dlqUnlinkf(headptr)
-     dlqlinkP	headptr;
+     dlqlinkP headptr;
 {
-    dlqlinkP	ptr;
+    dlqlinkP ptr;
     DLQ_ASSERT_HEAD(headptr);
 
-    if ( dlqEmpty(headptr) )
-	return(0);
+    if (dlqEmpty(headptr))
+	return (0);
 
     ptr = headptr->dlq_next;
 
@@ -156,7 +162,7 @@ dlqUnlinkf(headptr)
 
     ptr->dlq_next = ptr;
     ptr->dlq_prev = ptr;
-    return(ptr);
+    return (ptr);
 }
 
 /* dlqUnlink
@@ -164,11 +170,10 @@ dlqUnlinkf(headptr)
  */
 
 dlqUnlink(ptr)
-     dlqlinkP    ptr;
+     dlqlinkP ptr;
 {
     /* must not be the queue head */
-    if ( ptr->dlq_type == DLQ_HEAD )
-    {
+    if (ptr->dlq_type == DLQ_HEAD) {
 	printf("dlqUnlink: invalid unlink\n");
 	exit(1);
     }
@@ -186,55 +191,50 @@ dlqUnlink(ptr)
 
 dlqlinkP
 dlqFront(headptr)
-     dlqlinkP	headptr;
+     dlqlinkP headptr;
 {
     DLQ_ASSERT_HEAD(headptr);
 
-    if ( dlqEmpty(headptr) )
-	return(0);
+    if (dlqEmpty(headptr))
+	return (0);
 
-    return(headptr->dlq_next);
+    return (headptr->dlq_next);
 }
 
 int
 dlqCount(headptr)
-     dlqlinkP	headptr;
+     dlqlinkP headptr;
 {
-    dlqlinkP    ptr;
+    dlqlinkP ptr;
     int count = 0;
 
     DLQ_ASSERT_HEAD(headptr);
 
     ptr = headptr->dlq_next;
-    while ( ptr != headptr )
-    {
+    while (ptr != headptr) {
 	ptr = ptr->dlq_next;
 	count++;
     }
-    return(count);
+    return (count);
 }
 
 dlqTraverseQueue(headptr, fn1, fn2)
-     dlqlinkP	headptr;
-     int (*fn1)();
-     int (*fn2)();
+     dlqlinkP headptr;
+     int (*fn1) ();
+     int (*fn2) ();
 {
-    dlqlinkP    ptr, oldPtr;
+    dlqlinkP ptr, oldPtr;
 
     DLQ_ASSERT_HEAD(headptr);
 
     ptr = headptr->dlq_next;
-    while ( ptr != headptr )
-    {
+    while (ptr != headptr) {
 	if (fn2 && ptr->dlq_structPtr)
-	    (*fn2)(ptr->dlq_structPtr);
+	    (*fn2) (ptr->dlq_structPtr);
 	oldPtr = ptr;
 	ptr = ptr->dlq_next;
-	if (fn1) (*fn1)(oldPtr);
+	if (fn1)
+	    (*fn1) (oldPtr);
     }
-    return(0);
+    return (0);
 }
-
-
-
-
