@@ -44,8 +44,8 @@
 #ifndef __SMP__
 #define __SMP__
 #endif
-#define AFS_GLOBAL_SUNLOCK
 #endif
+#define AFS_GLOBAL_SUNLOCK
 
 #if defined(MODULE) && defined(CONFIG_MODVERSIONS)
 #define MODVERSIONS
@@ -57,12 +57,13 @@
 #include <afs/afs_sysnames.h>
 #define AFS_USERSPACE_IP_ADDR 1
 #define RXK_LISTENER_ENV 1
-#define AFS_GCPAGS       2	/* Set to Userdisabled, allow sysctl to override */
+#define AFS_GCPAGS       1
 
 #define AFSLITTLE_ENDIAN    1
 #define AFS_HAVE_FFS        1	/* Use system's ffs. */
 #define AFS_HAVE_STATVFS    0	/* System doesn't support statvfs */
 #define AFS_VM_RDWR_ENV            1	/* read/write implemented via VM */
+#define AFS_USE_GETTIMEOFDAY       1	/* use gettimeofday to implement rx clock */
 
 #ifdef KERNEL
 #ifndef MIN
