@@ -11,7 +11,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/des/make_e.c,v 1.1.1.3 2001/07/14 22:21:33 hartmans Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/des/make_e.c,v 1.4 2003/07/15 23:15:00 shadow Exp $");
 
 #include <mit-cpyright.h>
 #include <stdio.h>
@@ -24,24 +25,23 @@ main()
     register i;
 
     /* clear the output */
-    fprintf(stdout,"\n\tL2 = 0; R2 = 0;");
+    fprintf(stdout, "\n\tL2 = 0; R2 = 0;");
 
     /* only take bits from R1, put into either L2 or R2 */
     /* first setup E */
-    fprintf(stdout,"\n/* E operations */\n/* right to left */\n");
+    fprintf(stdout, "\n/* E operations */\n/* right to left */\n");
     /* first list mapping from left to left */
 
     for (i = 0; i <= 31; i++)
 	if (E[i] < 32)
-	    fprintf(stdout,
-		    "\n\tif (R1 & (1<<%d)) L2 |= 1<<%d;",E[i],i);
+	    fprintf(stdout, "\n\tif (R1 & (1<<%d)) L2 |= 1<<%d;", E[i], i);
 
-    fprintf(stdout,"\n\n/* now from right to right */\n");
+    fprintf(stdout, "\n\n/* now from right to right */\n");
     /*  list mapping from left to right */
     for (i = 32; i <= 47; i++)
-	if (E[i] <32)
-	    fprintf(stdout,
-		    "\n\tif (R1 & (1<<%d)) R2 |= 1<<%d;",E[i],i-32);
+	if (E[i] < 32)
+	    fprintf(stdout, "\n\tif (R1 & (1<<%d)) R2 |= 1<<%d;", E[i],
+		    i - 32);
 
-    fprintf(stdout,"\n");
+    fprintf(stdout, "\n");
 }
