@@ -19,7 +19,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/des/new_rnd_key.c,v 1.13.2.1 2004/08/25 07:09:37 shadow Exp $");
+    ("$Header: /cvs/openafs/src/des/new_rnd_key.c,v 1.13.2.3 2005/08/18 04:56:14 shadow Exp $");
 
 #ifndef KERNEL
 #include <stdio.h>
@@ -38,7 +38,6 @@ RCSID
 #include <strings.h>
 #endif
 #endif
-#include "stats.h"
 
 static afs_int32 des_set_sequence_number(des_cblock new_sequence_number);
 static afs_int32 des_generate_random_block(des_cblock block);
@@ -257,9 +256,6 @@ des_generate_random_block(des_cblock block)
 {
     int i;
 
-    LOCK_RXKAD_STATS;
-    rxkad_stats.des_randoms++;
-    UNLOCK_RXKAD_STATS;
     /*
      * Encrypt the sequence number to get the new random block:
      */
