@@ -16,7 +16,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/libadmin/samples/cm_client_config.c,v 1.1.1.5 2004/01/10 20:56:45 hartmans Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/libadmin/samples/cm_client_config.c,v 1.6 2003/10/24 06:26:10 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -32,18 +33,15 @@ pthread_mutex_t des_random_mutex = PTHREAD_MUTEX_INITIALIZER;
 pthread_mutex_t rxkad_random_mutex = PTHREAD_MUTEX_INITIALIZER;
 #endif /* AFS_DARWIN_ENV */
 
-void Usage()
+void
+Usage()
 {
-    fprintf(stderr,
-	    "Usage: cm_client_config <host> <port>\n");
+    fprintf(stderr, "Usage: cm_client_config <host> <port>\n");
     exit(1);
 }
 
-void ParseArgs(
-    int argc,
-    char *argv[],
-    char **srvrName,
-    long *srvrPort)
+void
+ParseArgs(int argc, char *argv[], char **srvrName, long *srvrPort)
 {
     char **argp = argv;
 
@@ -59,7 +57,8 @@ void ParseArgs(
 	Usage();
 }
 
-int main(int argc, char *argv[])
+int
+main(int argc, char *argv[])
 {
     int rc;
     afs_status_t st = 0;
@@ -107,9 +106,9 @@ int main(int argc, char *argv[])
 	exit(1);
     }
 
-    
-    printf("\nClient configuration for %s (port %d):\n\n",
-	   srvrName, srvrPort);
+
+    printf("\nClient configuration for %s (port %d):\n\n", srvrName,
+	   srvrPort);
     printf("    clientVersion:  %d\n", config.clientVersion);
     printf("    serverVersion:  %d\n", config.serverVersion);
     printf("    nChunkFiles:    %d\n", config.c.config_v1.nChunkFiles);
