@@ -17,7 +17,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/lwp/lwp.c,v 1.27.2.5 2005/03/27 20:22:03 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/lwp/lwp.c,v 1.27.2.7 2006/03/09 06:41:50 shadow Exp $");
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -80,6 +80,8 @@ extern char PRE_Block;		/* from preempt.c */
 #ifdef __s390__
 #define MINFRAME    96
 #define STACK_ALIGN 8
+#elif defined(AFS_DARWIN_ENV)
+#define STACK_ALIGN 16
 #else
 #define STACK_ALIGN 4
 #endif
@@ -145,9 +147,7 @@ int lwp_nextindex;
 int lwp_MinStackSize = 0;
 
 static int
-lwp_remove(p, q)
-     register PROCESS p;
-     register struct QUEUE *q;
+lwp_remove(register PROCESS p, register struct QUEUE *q)
 {
     /* Special test for only element on queue */
     if (q->count == 1)
@@ -166,9 +166,7 @@ lwp_remove(p, q)
 }
 
 static int
-insert(p, q)
-     register PROCESS p;
-     register struct QUEUE *q;
+insert(register PROCESS p, register struct QUEUE *q)
 {
     if (q->head == NULL) {	/* Queue is empty */
 	q->head = p;
@@ -184,9 +182,7 @@ insert(p, q)
 }
 
 static int
-move(p, from, to)
-     PROCESS p;
-     struct QUEUE *from, *to;
+move(PROCESS p, struct QUEUE *from, struct QUEUE *to)
 {
 
     lwp_remove(p, from);
@@ -248,8 +244,7 @@ LWP_QWait(void)
 }
 
 int
-LWP_QSignal(pid)
-     register PROCESS pid;
+LWP_QSignal(register PROCESS pid)
 {
     if (pid->status == QWAITING) {
 	pid->status = READY;
@@ -304,7 +299,11 @@ LWP_CreateProcess(int (*ep) (), int stacksize, int priority, void *parm,
 	    return LWP_ENOMEM;
 	}
 	if (stacksize < MINSTACK)
+#ifdef AFS_DARWIN_ENV
+	    stacksize = 1008;
+#else /* !AFS_DARWIN_ENV */
 	    stacksize = 1000;
+#endif /* !AFS_DARWIN_ENV */
 	else
 	    stacksize =
 		STACK_ALIGN * ((stacksize + STACK_ALIGN - 1) / STACK_ALIGN);
@@ -349,12 +348,21 @@ LWP_CreateProcess(int (*ep) (), int stacksize, int priority, void *parm,
 	stackptr -= stacksize;
 	stackmemory = stackptr;
 #else
-	if ((stackmemory = (char *)malloc(stacksize + 7)) == NULL) {
+#ifdef AFS_DARWIN_ENV
+	if ((stackmemory = (char *)malloc(stacksize + STACK_ALIGN - 1)) == NULL)
+#else /* !AFS_DARWIN_ENV */
+	if ((stackmemory = (char *)malloc(stacksize + 7)) == NULL)
+#endif /* !AFS_DARWIN_ENV */
+	{
 	    Set_LWP_RC();
 	    return LWP_ENOMEM;
 	}
 	/* Round stack pointer to byte boundary */
+#ifdef AFS_DARWIN_ENV
+	stackptr = (char *)(STACK_ALIGN * (((long)stackmemory + STACK_ALIGN - 1) / STACK_ALIGN));
+#else /* !AFS_DARWIN_ENV */
 	stackptr = (char *)(8 * (((long)stackmemory + 7) / 8));
+#endif /* !AFS_DARWIN_ENV */
 #endif
 	if (priority < 0 || priority >= MAX_PRIORITIES) {
 	    Set_LWP_RC();
@@ -379,8 +387,12 @@ LWP_CreateProcess(int (*ep) (), int stacksize, int priority, void *parm,
 		    stackptr + MINFRAME);
 #else
 #if defined(AFS_SGI62_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#ifdef sys_x86_darwin_80
+	savecontext(Create_Process_Part2, &temp2->context, stackptr + stacksize - 16 - sizeof(void *));	/* 16 = 2 * jmp_buf_type */
+#else /* !sys_x86_darwin_80 */
 	/* Need to have the sp on an 8-byte boundary for storing doubles. */
 	savecontext(Create_Process_Part2, &temp2->context, stackptr + stacksize - 16);	/* 16 = 2 * jmp_buf_type */
+#endif /* !sys_x86_darwin_80 */
 #else
 #if defined(AFS_SPARC64_LINUX20_ENV) || defined(AFS_SPARC_LINUX20_ENV)
 	savecontext(Create_Process_Part2, &temp2->context, stackptr + stacksize - 0x40);	/* lomgjmp does something
