@@ -36,7 +36,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/rxgen/rpc_hout.c,v 1.7 2003/07/15 23:16:40 shadow Exp $");
+    ("$Header: /cvs/openafs/src/rxgen/rpc_hout.c,v 1.7.2.3 2006/07/31 17:07:50 shadow Exp $");
 
 #include <stdio.h>
 #include <string.h>
@@ -223,8 +223,10 @@ psproc1(definition * defp, int callTconnF, char *type, char *prefix,
     f_print(fout, "\nextern %s %s%s%s(\n", type, prefix, defp->pc.proc_prefix,
 	    defp->pc.proc_name);
 
-    if (callTconnF) {
+    if (callTconnF == 1) {
 	f_print(fout, "\t/*IN */ struct rx_call *z_call");
+    } else if (callTconnF == 2) {
+	f_print(fout, "\tregister struct ubik_client *aclient, afs_int32 aflags");
     } else {
 	f_print(fout, "\t/*IN */ struct rx_connection *z_conn");
     }
@@ -259,8 +261,9 @@ static void
 psprocdef(definition * defp)
 {
     int split_flag = defp->pc.split_flag;
+    int multi_flag = defp->pc.multi_flag;
 
-    if (split_flag) {
+    if (split_flag || multi_flag) {
 	psproc1(defp, 1, "int", "Start",
 		(1 << DEF_INPARAM) | (1 << DEF_INOUTPARAM));
 	psproc1(defp, 1, "int", "End",
@@ -269,7 +272,11 @@ psprocdef(definition * defp)
 	psproc1(defp, 0, "int", "", 0xFFFFFFFF);
     }
 
-    psproc1(defp, 1, "afs_int32", "S", 0xFFFFFFFF);
+    if (uflag && !kflag)
+	psproc1(defp, 2, "int", "ubik_", 0xFFFFFFFF);
+
+    if (*ServerPrefix)
+	psproc1(defp, 1, "afs_int32", ServerPrefix, 0xFFFFFFFF);
 }
 
 
