@@ -10,14 +10,16 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/util/sys.c,v 1.1.1.4 2001/07/14 22:24:25 hartmans Exp $");
- 
+RCSID
+    ("$Header: /cvs/openafs/src/util/sys.c,v 1.6 2003/07/15 23:17:16 shadow Exp $");
+
 #include <stdio.h>
 
 #include "AFS_component_version_number.c"
 
-int main ()
+int
+main()
 {
-    printf ("%s\n", SYS_NAME);
+    printf("%s\n", SYS_NAME);
     return 0;
 }
