@@ -14,7 +14,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/venus/fstrace.c,v 1.16.2.3 2005/04/03 18:15:53 shadow Exp $");
+    ("$Header: /cvs/openafs/src/venus/fstrace.c,v 1.16.2.5 2005/10/05 05:58:48 shadow Exp $");
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -1491,7 +1491,11 @@ dce1_error_inq_text(status_to_convert, error_text, status)
     char nls_filename[11];
     char alt_filename[80];
     char *message;
+#if defined(AFS_64BITPOINTER_ENV)
+    long J;
+#else
     int J;
+#endif
     static char *facility_names[] = {
 	"xxx",
 	"afs"
@@ -1557,8 +1561,12 @@ dce1_error_inq_text(status_to_convert, error_text, status)
 #else
     catd = (nl_catd) catopen1(nls_filename, 0);
 #endif
+#else
+#if defined(AFS_64BITPOINTER_ENV)
+    J = (long)catopen(nls_filename, 0);
 #else
     J = (int)catopen(nls_filename, 0);
+#endif
     catd = (nl_catd) J;
 #endif
     if (catd == (nl_catd) - 1) {
@@ -1580,8 +1588,12 @@ dce1_error_inq_text(status_to_convert, error_text, status)
 #else
 	catd = (nl_catd) catopen1(alt_filename, 0);
 #endif
+#else
+#if defined(AFS_64BITPOINTER_ENV)
+        J = (long)catopen(alt_filename, 0);
 #else
 	J = (int)catopen(alt_filename, 0);
+#endif
 	catd = (nl_catd) J;
 #endif
 	if (catd == (nl_catd) - 1) {
@@ -2144,6 +2156,10 @@ afs_syscall(call, parm0, parm1, parm2, parm3, parm4, parm5, parm6)
     __asm__ __volatile__("mov	%o0, %i0; ret; restore");
 #endif
 #else
+#ifdef AFS_DARWIN80_ENV
+    code = ioctl_afs_syscall(call, parm0, parm1, parm2, parm3, parm4, parm5, &rval);
+    if (!code) code = rval;
+#else
 #if !defined(AFS_SGI_ENV) && !defined(AFS_AIX32_ENV)
     code = syscall(AFS_SYSCALL, call, parm0, parm1, parm2, parm3, parm4);
 #else
@@ -2153,6 +2169,7 @@ afs_syscall(call, parm0, parm1, parm2, parm3, parm4, parm5, parm6)
     code = syscall(AFSCALL_ICL, parm0, parm1, parm2, parm3, parm4);
 #endif
 #endif
+#endif
 #endif /* AFS_LINUX20_ENV */
     return code;
 }
