@@ -20,7 +20,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/viced/viced.c,v 1.58.2.11 2006/02/22 05:02:04 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/viced/viced.c,v 1.58.2.18 2006/09/15 23:19:28 jaltman Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -150,8 +150,6 @@ struct afsconf_dir *confDir;	/* Configuration dir object */
 
 int restartMode = RESTART_ORDINARY;
 
-int Testing = 0;		/* for ListViceInodes */
-
 /*
  * Home for the performance statistics.
  */
@@ -167,6 +165,7 @@ int SawPctSpare;
 int debuglevel = 0;
 int printBanner = 0;
 int rxJumbograms = 1;		/* default is to send and receive jumbograms. */
+int rxBind = 0;		/* don't bind */
 int rxMaxMTU = -1;
 afs_int32 implicitAdminRights = PRSFS_LOOKUP;	/* The ADMINISTER right is 
 						 * already implied */
@@ -197,6 +196,10 @@ int sendBufSize = 16384;	/* send buffer size */
 
 struct timeval tp;
 
+#ifdef AFS_PTHREAD_ENV
+pthread_key_t viced_uclient_key;
+#endif
+
 /*
  * FileServer's name and IP address, both network byte order and
  * host byte order.
@@ -738,6 +741,7 @@ FlagMsg()
     strcat(buffer, "[-rxdbg (enable rx debugging)] ");
     strcat(buffer, "[-rxdbge (enable rxevent debugging)] ");
     strcat(buffer, "[-rxmaxmtu <bytes>] ");
+    strcat(buffer, "[-rxbind (bind the Rx socket to one address)] ");
 #if AFS_PTHREAD_ENV
     strcat(buffer, "[-vattachpar <number of volume attach threads>] ");
 #endif
@@ -1054,6 +1058,8 @@ ParseArgs(int argc, char *argv[])
 #endif
 	else if (!strcmp(argv[i], "-nojumbo")) {
 	    rxJumbograms = 0;
+	} else if (!strcmp(argv[i], "-rxbind")) {
+	    rxBind = 1;
 	} else if (!strcmp(argv[i], "-rxmaxmtu")) {
 	    if ((i + 1) >= argc) {
 		fprintf(stderr, "missing argument for -rxmaxmtu\n"); 
@@ -1294,6 +1300,11 @@ InitPR()
 		("Couldn't initialize protection library; code=%d.\n", code));
 	return code;
     }
+
+#ifdef AFS_PTHREAD_ENV
+    assert(pthread_key_create(&viced_uclient_key, NULL) == 0);
+#endif
+
     SystemId = SYSADMINID;
     SystemAnyUser = ANYUSERID;
     SystemAnyUserCPS.prlist_len = 0;
@@ -1361,6 +1372,7 @@ vl_Initialize(char *confDir)
 			     info.hostAddr[i].sin_port, USER_SERVICE_ID, sc,
 			     scIndex);
     code = ubik_ClientInit(serverconns, &cstruct);
+    afsconf_Close(tdir);
     if (code) {
 	ViceLog(0, ("vl_Initialize: ubik client init failed.\n"));
 	return code;
@@ -1529,7 +1541,7 @@ Do_VLRegisterRPC()
 	FS_HostAddrs_HBO[i] = ntohl(FS_HostAddrs[i]);
     addrs.bulkaddrs_len = FS_HostAddr_cnt;
     addrs.bulkaddrs_val = (afs_uint32 *) FS_HostAddrs_HBO;
-    code = ubik_Call(VL_RegisterAddrs, cstruct, 0, &FS_HostUUID, 0, &addrs);
+    code = ubik_VL_RegisterAddrs(cstruct, 0, &FS_HostUUID, 0, &addrs);
     if (code) {
 	if (code == VL_MULTIPADDR) {
 	    ViceLog(0,
@@ -1554,6 +1566,43 @@ Do_VLRegisterRPC()
     return 0;
 }
 
+afs_int32
+SetupVL()
+{
+    afs_int32 code;
+    extern int rxi_numNetAddrs;
+    extern afs_uint32 rxi_NetAddrs[];
+
+#ifndef AFS_NT40_ENV
+    if (AFSDIR_SERVER_NETRESTRICT_FILEPATH || AFSDIR_SERVER_NETINFO_FILEPATH) {
+	/*
+	 * Find addresses we are supposed to register as per the netrestrict 
+	 * and netinfo files (/usr/afs/local/NetInfo and 
+	 * /usr/afs/local/NetRestict)
+	 */
+	char reason[1024];
+	afs_int32 code = parseNetFiles(FS_HostAddrs, NULL, NULL,
+				       ADDRSPERSITE, reason,
+				       AFSDIR_SERVER_NETINFO_FILEPATH,
+				       AFSDIR_SERVER_NETRESTRICT_FILEPATH);
+	if (code < 0) {
+	    ViceLog(0, ("Can't register any valid addresses: %s\n", reason));
+	    exit(1);
+	}
+	FS_HostAddr_cnt = (afs_uint32) code;
+    } else
+#endif
+    {
+	FS_HostAddr_cnt = rx_getAllAddr(FS_HostAddrs, ADDRSPERSITE);
+    }
+
+    if (FS_HostAddr_cnt == 1 && rxBind == 1)
+	code = FS_HostAddrs[0];
+    else 
+	code = htonl(INADDR_ANY);
+    return code;
+}
+
 afs_int32
 InitVL()
 {
@@ -1587,30 +1636,7 @@ InitVL()
     /* A good sysid file exists; inform the vlserver. If any conflicts,
      * we always use the latest interface available as the real truth.
      */
-#ifndef AFS_NT40_ENV
-    if (AFSDIR_SERVER_NETRESTRICT_FILEPATH || AFSDIR_SERVER_NETINFO_FILEPATH) {
-	/*
-	 * Find addresses we are supposed to register as per the netrestrict 
-	 * and netinfo files (/usr/afs/local/NetInfo and 
-	 * /usr/afs/local/NetRestict)
-	 */
-	char reason[1024];
-	afs_int32 code = parseNetFiles(FS_HostAddrs, NULL, NULL,
-				       ADDRSPERSITE, reason,
-				       AFSDIR_SERVER_NETINFO_FILEPATH,
-				       AFSDIR_SERVER_NETRESTRICT_FILEPATH);
-	if (code < 0) {
-	    ViceLog(0, ("Can't register any valid addresses: %s\n", reason));
-	    exit(1);
-	}
-	FS_HostAddr_cnt = (afs_uint32) code;
-    } else
-#endif
-    {
-	FS_HostAddr_cnt = rx_getAllAddr(FS_HostAddrs, ADDRSPERSITE);
-    }
 
-    FS_registered = 1;
     code = Do_VLRegisterRPC();
     return code;
 }
@@ -1635,6 +1661,7 @@ main(int argc, char *argv[])
 #endif
     int curLimit;
     time_t t;
+    afs_uint32 rx_bindhost;
 
 #ifdef	AFS_AIX32_ENV
     struct sigaction nsa;
@@ -1800,7 +1827,9 @@ main(int argc, char *argv[])
 #endif
     if (udpBufSize)
 	rx_SetUdpBufSize(udpBufSize);	/* set the UDP buffer size for receive */
-    if (rx_Init((int)htons(7000)) < 0) {
+    rx_bindhost = SetupVL();
+
+    if (rx_InitHost(rx_bindhost, (int)htons(7000)) < 0) {
 	ViceLog(0, ("Cannot initialize RX\n"));
 	exit(1);
     }
@@ -1817,17 +1846,17 @@ main(int argc, char *argv[])
     sc[1] = 0;			/* rxvab_NewServerSecurityObject(key1, 0) */
     sc[2] = rxkad_NewServerSecurityObject(rxkad_clear, NULL, get_key, NULL);
     sc[3] = rxkad_NewServerSecurityObject(rxkad_crypt, NULL, get_key, NULL);
-    tservice = rx_NewService( /* port */ 0, /* service id */ 1,	/*service name */
-			     "AFS",
-							/* security classes */ sc,
-							/* numb sec classes */
-			     4, RXAFS_ExecuteRequest);
+    tservice = rx_NewServiceHost(rx_bindhost,  /* port */ 0, /* service id */ 
+				 1,	/*service name */
+				 "AFS",
+				 /* security classes */ sc,
+				 /* numb sec classes */
+				 4, RXAFS_ExecuteRequest);
     if (!tservice) {
 	ViceLog(0,
 		("Failed to initialize RX, probably two servers running.\n"));
 	exit(-1);
     }
-    rx_SetDestroyConnProc(tservice, (void (*)())h_FreeConnection);
     rx_SetMinProcs(tservice, 3);
     rx_SetMaxProcs(tservice, lwps);
     rx_SetCheckReach(tservice, 1);
