@@ -12,7 +12,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vol/ntops.c,v 1.1.1.4 2001/07/14 22:24:57 hartmans Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/vol/ntops.c,v 1.7.2.2 2006/09/05 14:50:57 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <stdio.h>
@@ -40,6 +41,10 @@ RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vol/nto
 
 #define BASEFILEATTRIBUTE FILE_ATTRIBUTE_NORMAL
 
+int Testing = 0;
+
+static void AddToZLCDeleteList(char dir, char *name);
+
 /* nt_unlink - unlink a case sensitive name.
  *
  * nt_unlink supports the nt_dec call.
@@ -50,19 +55,19 @@ RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/vol/nto
  * call tries to create a new file with the same name. Fortunately, neither
  * case should occur as part of nt_dec.
  */
-int nt_unlink(char *name)
+int
+nt_unlink(char *name)
 {
     HANDLE fh;
-    
-    fh = CreateFile(name, GENERIC_READ|GENERIC_WRITE, 
+
+    fh = CreateFile(name, GENERIC_READ | GENERIC_WRITE,
 		    FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
 		    NULL, OPEN_EXISTING,
-		    BASEFILEATTRIBUTE | FILE_FLAG_DELETE_ON_CLOSE
-		    | FILE_FLAG_POSIX_SEMANTICS,
-		    NULL);
+		    BASEFILEATTRIBUTE | FILE_FLAG_DELETE_ON_CLOSE |
+		    FILE_FLAG_POSIX_SEMANTICS, NULL);
     if (fh != INVALID_HANDLE_VALUE)
 	CloseHandle(fh);
-    else { 
+    else {
 	errno = nterr_nt2unix(GetLastError(), ENOENT);
 	return -1;
     }
@@ -74,14 +79,15 @@ int nt_unlink(char *name)
  * Return Value:
  *	the handle or -1 on error.
  */
-FD_t nt_open(char *name, int flags, int mode)
+FD_t
+nt_open(char *name, int flags, int mode)
 {
     HANDLE fh;
     DWORD nt_access = 0;
     DWORD nt_share = FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE;
     DWORD nt_create = 0;
     /* Really use the sequential one for data files, random for meta data. */
-    DWORD FandA = BASEFILEATTRIBUTE | FILE_FLAG_SEQUENTIAL_SCAN ;
+    DWORD FandA = BASEFILEATTRIBUTE | FILE_FLAG_SEQUENTIAL_SCAN;
 
     /* set access */
     if ((flags & O_RDWR) || (flags & O_WRONLY))
@@ -92,25 +98,30 @@ FD_t nt_open(char *name, int flags, int mode)
     /* set creation */
     switch (flags & (O_CREAT | O_EXCL | O_TRUNC)) {
     case 0:
-	nt_create = OPEN_EXISTING; break;
+	nt_create = OPEN_EXISTING;
+	break;
     case O_CREAT:
-	nt_create = OPEN_ALWAYS; break;
+	nt_create = OPEN_ALWAYS;
+	break;
     case O_CREAT | O_TRUNC:
-	nt_create = CREATE_ALWAYS;  break;
+	nt_create = CREATE_ALWAYS;
+	break;
     case O_CREAT | O_EXCL:
     case O_CREAT | O_EXCL | O_TRUNC:
-	nt_create = CREATE_NEW; break;
+	nt_create = CREATE_NEW;
+	break;
     case O_TRUNC:
-	nt_create = TRUNCATE_EXISTING; break;
+	nt_create = TRUNCATE_EXISTING;
+	break;
     case O_TRUNC | O_EXCL:
     case O_EXCL:
     default:
-	errno = EINVAL; return INVALID_FD;
+	errno = EINVAL;
+	return INVALID_FD;
 	break;
     }
 
-    fh = CreateFile(name, nt_access, nt_share, NULL, nt_create,
-		    FandA, NULL);
+    fh = CreateFile(name, nt_access, nt_share, NULL, nt_create, FandA, NULL);
 
     if (fh == INVALID_HANDLE_VALUE) {
 	fh = INVALID_FD;
@@ -119,7 +130,8 @@ FD_t nt_open(char *name, int flags, int mode)
     return fh;
 }
 
-int nt_close(FD_t fd)
+int
+nt_close(FD_t fd)
 {
     BOOL code;
 
@@ -131,12 +143,13 @@ int nt_close(FD_t fd)
     return 0;
 }
 
-int nt_write(FD_t fd, char *buf, size_t size)
+int
+nt_write(FD_t fd, char *buf, size_t size)
 {
     BOOL code;
     DWORD nbytes;
 
-    code = WriteFile((HANDLE)fd, (void*)buf, (DWORD)size, &nbytes, NULL);
+    code = WriteFile((HANDLE) fd, (void *)buf, (DWORD) size, &nbytes, NULL);
 
     if (!code) {
 	errno = nterr_nt2unix(GetLastError(), EBADF);
@@ -145,12 +158,13 @@ int nt_write(FD_t fd, char *buf, size_t size)
     return (int)nbytes;
 }
 
-int nt_read(FD_t fd, char *buf, size_t size)
+int
+nt_read(FD_t fd, char *buf, size_t size)
 {
     BOOL code;
     DWORD nbytes;
 
-    code = ReadFile((HANDLE)fd, (void*)buf, (DWORD)size, &nbytes, NULL);
+    code = ReadFile((HANDLE) fd, (void *)buf, (DWORD) size, &nbytes, NULL);
 
     if (!code) {
 	errno = nterr_nt2unix(GetLastError(), EBADF);
@@ -159,7 +173,8 @@ int nt_read(FD_t fd, char *buf, size_t size)
     return (int)nbytes;
 }
 
-int nt_iread(IHandle_t *h, int offset, char *buf, int size)
+int
+nt_iread(IHandle_t * h, int offset, char *buf, int size)
 {
     int nBytes;
     FdHandle_t *fdP;
@@ -168,7 +183,7 @@ int nt_iread(IHandle_t *h, int offset, char *buf, int size)
     if (fdP == NULL)
 	return -1;
 
-    if (FDH_SEEK(fdP, offset, SEEK_SET)<0) {
+    if (FDH_SEEK(fdP, offset, SEEK_SET) < 0) {
 	FDH_REALLYCLOSE(fdP);
 	return -1;
     }
@@ -178,7 +193,8 @@ int nt_iread(IHandle_t *h, int offset, char *buf, int size)
     return nBytes;
 }
 
-int nt_iwrite(IHandle_t *h, int offset, char *buf, int size)
+int
+nt_iwrite(IHandle_t * h, int offset, char *buf, int size)
 {
     int nBytes;
     FdHandle_t *fdP;
@@ -187,7 +203,7 @@ int nt_iwrite(IHandle_t *h, int offset, char *buf, int size)
     if (fdP == NULL)
 	return -1;
 
-    if (FDH_SEEK(fdP, offset, SEEK_SET)<0) {
+    if (FDH_SEEK(fdP, offset, SEEK_SET) < 0) {
 	FDH_REALLYCLOSE(fdP);
 	return -1;
     }
@@ -197,7 +213,8 @@ int nt_iwrite(IHandle_t *h, int offset, char *buf, int size)
 }
 
 
-int nt_size(FD_t fd)
+int
+nt_size(FD_t fd)
 {
     BY_HANDLE_FILE_INFORMATION finfo;
 
@@ -208,7 +225,8 @@ int nt_size(FD_t fd)
 }
 
 
-int nt_getFileCreationTime(FD_t fd, FILETIME *ftime)
+int
+nt_getFileCreationTime(FD_t fd, FILETIME * ftime)
 {
     BY_HANDLE_FILE_INFORMATION finfo;
 
@@ -220,31 +238,33 @@ int nt_getFileCreationTime(FD_t fd, FILETIME *ftime)
     return 0;
 }
 
-int nt_setFileCreationTime(FD_t fd, FILETIME *ftime)
+int
+nt_setFileCreationTime(FD_t fd, FILETIME * ftime)
 {
     return !SetFileTime(fd, ftime, NULL, NULL);
 }
 
-int nt_sync(int cdrive)
+int
+nt_sync(int cdrive)
 {
     FD_t drive_fd;
     char sdrive[32];
     int n;
 
     n = cdrive;
-    if (n<=26) {
-	cdrive = 'A' + (n-1);
+    if (n <= 26) {
+	cdrive = 'A' + (n - 1);
     }
 
     cdrive = _toupper(cdrive);
 
-    (void) sprintf(sdrive, "\\\\.\\%c:", cdrive);
-    drive_fd = nt_open(sdrive , O_RDWR, 0666);
+    (void)sprintf(sdrive, "\\\\.\\%c:", cdrive);
+    drive_fd = nt_open(sdrive, O_RDWR, 0666);
     if (drive_fd == INVALID_FD) {
 	return -1;
     }
 
-    if (!FlushFileBuffers((HANDLE)drive_fd)) {
+    if (!FlushFileBuffers((HANDLE) drive_fd)) {
 	errno = nterr_nt2unix(GetLastError(), EBADF);
 	nt_close(drive_fd);
 	return -1;
@@ -255,9 +275,10 @@ int nt_sync(int cdrive)
 
 
 /* Currently nt_ftruncate only tested to shrink a file. */
-int nt_ftruncate(FD_t fd, int len)
+int
+nt_ftruncate(FD_t fd, int len)
 {
-    if (SetFilePointer(fd, (LONG)len, NULL, FILE_BEGIN)
+    if (SetFilePointer(fd, (LONG) len, NULL, FILE_BEGIN)
 	== 0xffffffff) {
 	errno = nterr_nt2unix(GetLastError(), EBADF);
 	return -1;
@@ -270,14 +291,16 @@ int nt_ftruncate(FD_t fd, int len)
 }
 
 
-int nt_fsync(FD_t fd)
+int
+nt_fsync(FD_t fd)
 {
     int code = FlushFileBuffers(fd);
     return code == 0 ? -1 : 0;
 }
 
 
-int nt_seek(FD_t fd, int off, int where)
+int
+nt_seek(FD_t fd, int off, int where)
 {
     int code = SetFilePointer(fd, off, NULL, where);
     return code;
@@ -298,15 +321,15 @@ int nt_seek(FD_t fd, int off, int where)
 #define NT_TAGSHIFT     32
 #define NT_INODESPECIAL 0x2000000000
 
-#define NT_MAXVOLS 5 /* Maximum supported number of volumes per volume
-		      * group, not counting temporary (move) volumes.
-		      * This is the number of separate files, all having
-		      * the same vnode number, which can occur in a volume
-		      * group at once.
-		      */
+#define NT_MAXVOLS 5		/* Maximum supported number of volumes per volume
+				 * group, not counting temporary (move) volumes.
+				 * This is the number of separate files, all having
+				 * the same vnode number, which can occur in a volume
+				 * group at once.
+				 */
 
-		       
-int nt_SetLinkCount(FdHandle_t *h, Inode ino, int count, int locked);
+
+int nt_SetLinkCount(FdHandle_t * h, Inode ino, int count, int locked);
 
 
 /* nt_DevToDrive 
@@ -320,30 +343,33 @@ int nt_SetLinkCount(FdHandle_t *h, Inode ino, int count, int locked);
  * Returns pointer to end of drive if successful, else NULL.
  *
  */
-char * nt_DevToDrive(char *drive, int dev)
+char *
+nt_DevToDrive(char *drive, int dev)
 {
     if (dev < 2 || dev > 25) {
 	errno = EINVAL;
-	return NULL; /* Invalid drive */
+	return NULL;		/* Invalid drive */
     }
     drive[0] = (char)('A' + dev);
     drive[1] = ':';
     drive[2] = '\0';
-    
-    return drive+2;
+
+    return drive + 2;
 
 }
 
 /* Returns pointer to end of name if successful, else NULL. */
-char * nt_HandleToVolDir(char *name, IHandle_t *h)
+char *
+nt_HandleToVolDir(char *name, IHandle_t * h)
 {
     b32_string_t str1;
 
-    if (!(name = nt_DevToDrive(name, h->ih_dev))) return NULL;
+    if (!(name = nt_DevToDrive(name, h->ih_dev)))
+	return NULL;
 
-    (void) memcpy(name, "\\Vol_", 5);
+    (void)memcpy(name, "\\Vol_", 5);
     name += 5;
-    (void) strcpy(name, int_to_base32(str1, h->ih_vid));
+    (void)strcpy(name, int_to_base32(str1, h->ih_vid));
     name += strlen(name);
     memcpy(name, ".data", 5);
     name += 5;
@@ -356,13 +382,15 @@ char * nt_HandleToVolDir(char *name, IHandle_t *h)
  *
  * Constructs a file name for the fully qualified handle.
  */
-int nt_HandleToName(char *name, IHandle_t *h)
+int
+nt_HandleToName(char *name, IHandle_t * h)
 {
     b32_string_t str1;
-    int tag = (int)((h->ih_ino>>NT_TAGSHIFT) & NT_TAGMASK);
+    int tag = (int)((h->ih_ino >> NT_TAGSHIFT) & NT_TAGMASK);
     int vno = (int)(h->ih_ino & NT_VNODEMASK);
-	
-    if (!(name = nt_HandleToVolDir(name, h))) return -1;
+
+    if (!(name = nt_HandleToVolDir(name, h)))
+	return -1;
 
     str1[0] = '\\';
     if (h->ih_ino & NT_INODESPECIAL)
@@ -371,17 +399,17 @@ int nt_HandleToName(char *name, IHandle_t *h)
 	if (vno & 0x1)
 	    str1[1] = 'Q';
 	else
-	    str1[1] = ((vno & 0x1f)>>1) + 'A';
+	    str1[1] = ((vno & 0x1f) >> 1) + 'A';
     }
 
     memcpy(name, str1, 2);
     name += 2;
-    (void) memcpy(name, "\\V_", 3);
+    (void)memcpy(name, "\\V_", 3);
     name += 3;
-    (void) strcpy(name,  int_to_base32(str1, vno));
+    (void)strcpy(name, int_to_base32(str1, vno));
     name += strlen(name);
     *(name++) = '.';
-    (void) strcpy(name,  int_to_base32(str1, tag));
+    (void)strcpy(name, int_to_base32(str1, tag));
     name += strlen(name);
     *name = '\0';
 
@@ -401,7 +429,8 @@ int nt_HandleToName(char *name, IHandle_t *h)
  * Q ----- data directory
  * R ----- special files directory
  */
-static int nt_CreateDataDirectories(IHandle_t *h, int *created)
+static int
+nt_CreateDataDirectories(IHandle_t * h, int *created)
 {
     char name[128];
     char *s;
@@ -409,23 +438,22 @@ static int nt_CreateDataDirectories(IHandle_t *h, int *created)
 
     if (!(s = nt_HandleToVolDir(name, h)))
 	return -1;
-    
-    if (mkdir(name)<0) {
+
+    if (mkdir(name) < 0) {
 	if (errno != EEXIST)
 	    return -1;
-    }
-    else
+    } else
 	*created = 1;
 
     *s++ = '\\';
-    *(s+1) = '\0';
-    for (i = 'A'; i <= 'R' ; i++) {
+    *(s + 1) = '\0';
+    for (i = 'A'; i <= 'R'; i++) {
 	*s = (char)i;
-	if (mkdir(name)<0 && errno != EEXIST)
+	if (mkdir(name) < 0 && errno != EEXIST)
 	    return -1;
     }
     return 0;
-}	
+}
 
 /* nt_RemoveDataDirectories
  *
@@ -433,7 +461,8 @@ static int nt_CreateDataDirectories(IHandle_t *h, int *created)
  * can continue running if the removes fail. The salvage process will
  * finish tidying up for us.
  */
-static int nt_RemoveDataDirectories(IHandle_t *h)
+static int
+nt_RemoveDataDirectories(IHandle_t * h)
 {
     char name[128];
     char *s;
@@ -443,22 +472,22 @@ static int nt_RemoveDataDirectories(IHandle_t *h)
 	return -1;
 
     *s++ = '\\';
-    *(s+1) = '\0';
-    for (i = 'A'; i <= 'R' ; i++) {
+    *(s + 1) = '\0';
+    for (i = 'A'; i <= 'R'; i++) {
 	*s = (char)i;
-	if (rmdir(name)<0 && errno != ENOENT)
+	if (rmdir(name) < 0 && errno != ENOENT)
 	    return -1;
     }
 
     /* Delete the Vol_NNNNNN.data directory. */
     s--;
     *s = '\0';
-    if (rmdir(name)<0 && errno != ENOENT) {
+    if (rmdir(name) < 0 && errno != ENOENT) {
 	return -1;
     }
-    
+
     return 0;
-}	
+}
 
 
 /* Create the file in the name space.
@@ -486,12 +515,14 @@ static int nt_RemoveDataDirectories(IHandle_t *h)
  * This function is called by VCreateVolume to hide the implementation
  * details of the inode numbers.
  */
-Inode nt_MakeSpecIno(int type)
+Inode
+nt_MakeSpecIno(int type)
 {
-    return ((Inode)type | (Inode)NT_INODESPECIAL);
+    return ((Inode) type | (Inode) NT_INODESPECIAL);
 }
 
-Inode nt_icreate(IHandle_t *h, char *part, int p1, int p2, int p3, int p4)
+Inode
+nt_icreate(IHandle_t * h, char *part, int p1, int p2, int p3, int p4)
 {
     char filename[128];
     b32_string_t str1;
@@ -506,26 +537,25 @@ Inode nt_icreate(IHandle_t *h, char *part, int p1, int p2, int p3, int p4)
     FdHandle_t tfd;
     int save_errno;
 
-    memset((void*)&tmp, 0, sizeof(IHandle_t));
+    memset((void *)&tmp, 0, sizeof(IHandle_t));
 
 
     tmp.ih_dev = tolower(*part) - 'a';
 
-    if (p2 == -1 ) {
-	tmp.ih_vid = p4; /* Use parent volume id, where this file will be.*/
+    if (p2 == -1) {
+	tmp.ih_vid = p4;	/* Use parent volume id, where this file will be. */
 
-	if (nt_CreateDataDirectories(&tmp, &created_dir)<0)
+	if (nt_CreateDataDirectories(&tmp, &created_dir) < 0)
 	    goto bad;
 
 	tmp.ih_ino = nt_MakeSpecIno(p3);
 	ftime.dwHighDateTime = p1;
 	ftime.dwLowDateTime = p2;
-    }
-    else {
+    } else {
 	/* Regular file or directory.
 	 * Encoding: p1 -> dir,  p2 -> name, p3,p4 -> Create time
 	 */
-	tmp.ih_ino = (Inode)p2;
+	tmp.ih_ino = (Inode) p2;
 	tmp.ih_vid = p1;
 
 	ftime.dwHighDateTime = p3;
@@ -533,14 +563,14 @@ Inode nt_icreate(IHandle_t *h, char *part, int p1, int p2, int p3, int p4)
     }
 
     /* Now create file. */
-    if ((code = nt_HandleToName(filename, &tmp))<0)
+    if ((code = nt_HandleToName(filename, &tmp)) < 0)
 	goto bad;
 
     p = filename + strlen(filename);
-    p --;
-    for (i=0; i<NT_MAXVOLS; i++) {
-	*p =  *int_to_base32(str1, i);
-	fd = nt_open(filename, O_CREAT|O_RDWR|O_TRUNC|O_EXCL, 0666);
+    p--;
+    for (i = 0; i < NT_MAXVOLS; i++) {
+	*p = *int_to_base32(str1, i);
+	fd = nt_open(filename, O_CREAT | O_RDWR | O_TRUNC | O_EXCL, 0666);
 	if (fd != INVALID_FD)
 	    break;
 	if (p2 == -1 && p3 == VI_LINKTABLE)
@@ -551,11 +581,11 @@ Inode nt_icreate(IHandle_t *h, char *part, int p1, int p2, int p3, int p4)
 	goto bad;
     }
 
-    tmp.ih_ino &= ~((Inode)NT_TAGMASK << NT_TAGSHIFT);
-    tmp.ih_ino |= ((Inode)i << NT_TAGSHIFT);
-    
+    tmp.ih_ino &= ~((Inode) NT_TAGMASK << NT_TAGSHIFT);
+    tmp.ih_ino |= ((Inode) i << NT_TAGSHIFT);
+
     if (!code) {
-	if (!SetFileTime((HANDLE)fd, &ftime, NULL, NULL)) {
+	if (!SetFileTime((HANDLE) fd, &ftime, NULL, NULL)) {
 	    errno = EBADF;
 	    code = -1;
 	}
@@ -578,17 +608,16 @@ Inode nt_icreate(IHandle_t *h, char *part, int p1, int p2, int p3, int p4)
 	    }
 	    code = nt_SetLinkCount(fdP, tmp.ih_ino, 1, 0);
 	    FDH_CLOSE(fdP);
-	}
-	else if (p2 == -1 && p3 == VI_LINKTABLE) {
+	} else if (p2 == -1 && p3 == VI_LINKTABLE) {
 	    if (fd == INVALID_FD)
 		goto bad;
 	    /* hack at tmp to setup for set link count call. */
 	    tfd.fd_fd = fd;
-	    code = nt_SetLinkCount(&tfd, (Inode)0, 1, 0);
+	    code = nt_SetLinkCount(&tfd, (Inode) 0, 1, 0);
 	}
     }
 
-bad:
+  bad:
     if (fd != INVALID_FD)
 	nt_close(fd);
 
@@ -597,19 +626,20 @@ bad:
 	nt_RemoveDataDirectories(&tmp);
 	errno = save_errno;
     }
-    return code ? (Inode)-1 : tmp.ih_ino;
+    return code ? (Inode) - 1 : tmp.ih_ino;
 }
 
 
-FD_t nt_iopen(IHandle_t *h)
+FD_t
+nt_iopen(IHandle_t * h)
 {
     FD_t fd;
     char name[128];
 
     /* Convert handle to file name. */
-    if (nt_HandleToName(name, h)<0)
+    if (nt_HandleToName(name, h) < 0)
 	return INVALID_FD;
-    
+
     fd = nt_open(name, O_RDWR, 0666);
     return fd;
 }
@@ -618,7 +648,8 @@ FD_t nt_iopen(IHandle_t *h)
  * handle passed in _is_ for the inode. We only check p1 for the special
  * files.
  */
-int nt_dec(IHandle_t *h, Inode ino, int p1)
+int
+nt_dec(IHandle_t * h, Inode ino, int p1)
 {
     int count = 0;
     char name[128];
@@ -634,86 +665,86 @@ int nt_dec(IHandle_t *h, Inode ino, int p1)
 	/* Verify this is the right file. */
 	IH_INIT(tmp, h->ih_dev, h->ih_vid, ino);
 
-	if (nt_HandleToName(name, tmp)<0) {
+	if (nt_HandleToName(name, tmp) < 0) {
 	    IH_RELEASE(tmp);
 	    errno = EINVAL;
 	    return -1;
 	}
 
-	dirH = FindFirstFileEx(name,  FindExInfoStandard, &info,
-			       FindExSearchNameMatch, NULL,
-			       FIND_FIRST_EX_CASE_SENSITIVE);
+	dirH =
+	    FindFirstFileEx(name, FindExInfoStandard, &info,
+			    FindExSearchNameMatch, NULL,
+			    FIND_FIRST_EX_CASE_SENSITIVE);
 	if (!dirH) {
 	    IH_RELEASE(tmp);
 	    errno = ENOENT;
-	    return -1; /* Can't get info, leave alone */
+	    return -1;		/* Can't get info, leave alone */
 	}
 
 	FindClose(dirH);
 	if (info.ftCreationTime.dwHighDateTime != (unsigned int)p1) {
 	    IH_RELEASE(tmp);
 	    return -1;
-        }
-	
+	}
+
 	/* If it's the link table itself, decrement the link count. */
 	if ((ino & NT_VNODEMASK) == VI_LINKTABLE) {
 	    fdP = IH_OPEN(tmp);
-	    if(fdP == NULL) {
+	    if (fdP == NULL) {
 		IH_RELEASE(tmp);
 		return -1;
 	    }
 
-	    if ((count = nt_GetLinkCount(fdP, (Inode)0, 1))<0) {
+	    if ((count = nt_GetLinkCount(fdP, (Inode) 0, 1)) < 0) {
 		FDH_REALLYCLOSE(fdP);
 		IH_RELEASE(tmp);
 		return -1;
 	    }
 
-	    count --;
-	    if (nt_SetLinkCount(fdP, (Inode)0, count<0 ? 0 : count, 1)<0) {
+	    count--;
+	    if (nt_SetLinkCount(fdP, (Inode) 0, count < 0 ? 0 : count, 1) < 0) {
 		FDH_REALLYCLOSE(fdP);
 		IH_RELEASE(tmp);
 		return -1;
 	    }
 
 	    FDH_REALLYCLOSE(fdP);
-	    if (count>0) {
+	    if (count > 0) {
 		IH_RELEASE(tmp);
 		return 0;
 	    }
 	}
-	
+
 	if ((code = nt_unlink(name)) == 0) {
 	    if ((ino & NT_VNODEMASK) == VI_LINKTABLE) {
 		/* Try to remove directory. If it fails, that's ok.
 		 * Salvage will clean up.
 		 */
-		(void) nt_RemoveDataDirectories(tmp);
+		(void)nt_RemoveDataDirectories(tmp);
 	    }
 	}
 
 	IH_RELEASE(tmp);
-    }
-    else {
+    } else {
 	/* Get a file descriptor handle for this Inode */
 	fdP = IH_OPEN(h);
 	if (fdP == NULL) {
 	    return -1;
 	}
 
-	if ((count = nt_GetLinkCount(fdP, ino,  1))<0) {
+	if ((count = nt_GetLinkCount(fdP, ino, 1)) < 0) {
 	    FDH_REALLYCLOSE(fdP);
 	    return -1;
 	}
 
-	count --;
+	count--;
 	if (count >= 0) {
-	    if (nt_SetLinkCount(fdP, ino, count, 1)<0) {
+	    if (nt_SetLinkCount(fdP, ino, count, 1) < 0) {
 		FDH_REALLYCLOSE(fdP);
 		return -1;
 	    }
 	}
-	if (count == 0 ) {
+	if (count == 0) {
 	    IHandle_t th = *h;
 	    th.ih_ino = ino;
 	    nt_HandleToName(name, &th);
@@ -725,7 +756,8 @@ int nt_dec(IHandle_t *h, Inode ino, int p1)
     return code;
 }
 
-int nt_inc(IHandle_t *h, Inode ino, int p1)
+int
+nt_inc(IHandle_t * h, Inode ino, int p1)
 {
     int count;
     int code = 0;
@@ -734,7 +766,7 @@ int nt_inc(IHandle_t *h, Inode ino, int p1)
     if (ino & NT_INODESPECIAL) {
 	if ((ino & NT_VNODEMASK) != VI_LINKTABLE)
 	    return 0;
-	ino = (Inode)0;
+	ino = (Inode) 0;
     }
 
     /* Get a file descriptor handle for this Inode */
@@ -743,16 +775,16 @@ int nt_inc(IHandle_t *h, Inode ino, int p1)
 	return -1;
     }
 
-    if ((count = nt_GetLinkCount(fdP, ino, 1))<0)
+    if ((count = nt_GetLinkCount(fdP, ino, 1)) < 0)
 	code = -1;
     else {
-	count ++;
+	count++;
 	if (count > 7) {
 	    errno = EINVAL;
 	    code = -1;
 	    count = 7;
 	}
-	if (nt_SetLinkCount(fdP, ino, count, 1)<0)
+	if (nt_SetLinkCount(fdP, ino, count, 1) < 0)
 	    code = -1;
     }
     if (code) {
@@ -790,14 +822,15 @@ int nt_inc(IHandle_t *h, Inode ino, int p1)
  * in the link table.
  */
 #define LINKTABLE_WIDTH 2
-#define LINKTABLE_SHIFT 1 /* log 2 = 1 */
+#define LINKTABLE_SHIFT 1	/* log 2 = 1 */
 
-static void nt_GetLCOffsetAndIndexFromIno(Inode ino, int *offset, int *index)
+static void
+nt_GetLCOffsetAndIndexFromIno(Inode ino, int *offset, int *index)
 {
-    int toff = (int) (ino & NT_VNODEMASK);
-    int tindex = (int)((ino>>NT_TAGSHIFT) & NT_TAGMASK);
+    int toff = (int)(ino & NT_VNODEMASK);
+    int tindex = (int)((ino >> NT_TAGSHIFT) & NT_TAGMASK);
 
-    *offset = (toff << LINKTABLE_SHIFT) + 8; /* *2 + sizeof stamp */
+    *offset = (toff << LINKTABLE_SHIFT) + 8;	/* *2 + sizeof stamp */
     *index = (tindex << 1) + tindex;
 }
 
@@ -806,12 +839,17 @@ static void nt_GetLCOffsetAndIndexFromIno(Inode ino, int *offset, int *index)
  * If lockit is set, lock the file and leave it locked upon a successful
  * return.
  */
-int nt_GetLinkCount(FdHandle_t *h, Inode ino, int lockit)
+static int
+nt_GetLinkCountInternal(FdHandle_t * h, Inode ino, int lockit, int fixup)
 {
     unsigned short row = 0;
-    int junk;
+    DWORD bytesRead, bytesWritten;
     int offset, index;
 
+    /* there's no linktable yet. the salvager will create one later */
+    if (h->fd_fd == INVALID_HANDLE_VALUE && fixup)
+       return 1;
+
     nt_GetLCOffsetAndIndexFromIno(ino, &offset, &index);
 
     if (lockit) {
@@ -819,33 +857,59 @@ int nt_GetLinkCount(FdHandle_t *h, Inode ino, int lockit)
 	    return -1;
     }
 
-    if (!SetFilePointer(h->fd_fd, (LONG)offset, NULL, FILE_BEGIN))
+    if (!SetFilePointer(h->fd_fd, (LONG) offset, NULL, FILE_BEGIN))
+	goto bad_getLinkByte;
+
+    if (!ReadFile(h->fd_fd, (void *)&row, 2, &bytesRead, NULL)) 
 	goto bad_getLinkByte;
     
-    if (!ReadFile(h->fd_fd, (void*)&row, 2, &junk, NULL)) {
-	goto bad_getLinkByte;
-    }
-	
-    return (int) ((row >> index) & NT_TAGMASK);
+    if (bytesRead == 0 && fixup) { 
+	LARGE_INTEGER size;
 
- bad_getLinkByte:
+	if (!GetFileSizeEx(h->fd_fd, &size) || size.QuadPart >= offset+sizeof(row))
+	    goto bad_getLinkByte;
+	FDH_TRUNC(h, offset+sizeof(row));
+	row = 1 << index;
+      rewrite:
+	WriteFile(h->fd_fd, (char *)&row, sizeof(row), &bytesWritten, NULL);
+    }
+
+    if (fixup && !((row >> index) & NT_TAGMASK)) {
+        row |= 1<<index;
+        goto rewrite;
+    }
+ 
+    return (int)((row >> index) & NT_TAGMASK);
+
+  bad_getLinkByte:
     if (lockit)
 	UnlockFile(h->fd_fd, offset, 0, 2, 0);
     return -1;
 }
 
+int
+nt_GetLinkCount(FdHandle_t * h, Inode ino, int lockit)
+{
+    return nt_GetLinkCountInternal(h, ino, lockit, 0);
+}
 
+void
+nt_SetNonZLC(FdHandle_t * h, Inode ino) 
+{
+    (void)nt_GetLinkCountInternal(h, ino, 0, 1);
+}
 
 
 /* nt_SetLinkCount
  * If locked is set, assume file is locked. Otherwise, lock file before
  * proceeding to modify it.
  */
-int nt_SetLinkCount(FdHandle_t *h, Inode ino, int count, int locked)
+int
+nt_SetLinkCount(FdHandle_t * h, Inode ino, int count, int locked)
 {
     int offset, index;
     unsigned short row;
-    int junk;
+    DWORD bytesRead, bytesWritten;
     int code = -1;
 
     nt_GetLCOffsetAndIndexFromIno(ino, &offset, &index);
@@ -857,38 +921,38 @@ int nt_SetLinkCount(FdHandle_t *h, Inode ino, int count, int locked)
 	    return -1;
 	}
     }
-    if (!SetFilePointer(h->fd_fd, (LONG)offset, NULL, FILE_BEGIN)) {
+    if (!SetFilePointer(h->fd_fd, (LONG) offset, NULL, FILE_BEGIN)) {
 	errno = nterr_nt2unix(GetLastError(), EBADF);
 	goto bad_SetLinkCount;
     }
 
-    
-    if (!ReadFile(h->fd_fd, (void*)&row, 2, &junk, NULL)) {
+
+    if (!ReadFile(h->fd_fd, (void *)&row, 2, &bytesRead, NULL)) {
 	errno = nterr_nt2unix(GetLastError(), EBADF);
 	goto bad_SetLinkCount;
     }
-    if (junk == 0)
+    if (bytesRead == 0)
 	row = 0;
-    
-    junk = 7 << index;
+
+    bytesRead = 7 << index;
     count <<= index;
-    row &= (unsigned short)~junk;
+    row &= (unsigned short)~bytesRead;
     row |= (unsigned short)count;
 
-    if (!SetFilePointer(h->fd_fd, (LONG)offset, NULL, FILE_BEGIN)) {
+    if (!SetFilePointer(h->fd_fd, (LONG) offset, NULL, FILE_BEGIN)) {
 	errno = nterr_nt2unix(GetLastError(), EBADF);
 	goto bad_SetLinkCount;
     }
 
-    if (!WriteFile(h->fd_fd, (void*)&row, 2, &junk, NULL)) {
+    if (!WriteFile(h->fd_fd, (void *)&row, 2, &bytesWritten, NULL)) {
 	errno = nterr_nt2unix(GetLastError(), EBADF);
 	goto bad_SetLinkCount;
     }
 
     code = 0;
 
-    
-bad_SetLinkCount:
+
+  bad_SetLinkCount:
     UnlockFile(h->fd_fd, offset, 0, 2, 0);
 
     return code;
@@ -898,12 +962,12 @@ bad_SetLinkCount:
 /* ListViceInodes - write inode data to a results file. */
 static int DecodeInodeName(char *name, int *p1, int *p2);
 static int DecodeVolumeName(char *name, int *vid);
-static int nt_ListAFSSubDirs(IHandle_t *dirIH,
-			     int (*write_fun)(FILE *, struct ViceInodeInfo *,
-					      char *, char *),
-			     FILE *fp,
-			     int (*judgeFun)(struct ViceInodeInfo *, int vid),
-			     int singleVolumeNumber);
+static int nt_ListAFSSubDirs(IHandle_t * dirIH,
+			     int (*write_fun) (FILE *, struct ViceInodeInfo *,
+					       char *, char *), FILE * fp,
+			     int (*judgeFun) (struct ViceInodeInfo *,
+					      int vid, void *rock),
+			     int singleVolumeNumber, void *rock);
 
 
 /* WriteInodeInfo
@@ -915,8 +979,8 @@ static int nt_ListAFSSubDirs(IHandle_t *dirIH,
  * This is written as a callback simply so that other listing routines
  * can use the same inode reading code.
  */
-static int WriteInodeInfo(FILE *fp, struct ViceInodeInfo *info, char *dir,
-			  char *name)
+static int
+WriteInodeInfo(FILE * fp, struct ViceInodeInfo *info, char *dir, char *name)
 {
     int n;
     n = fwrite(info, sizeof(*info), 1, fp);
@@ -937,12 +1001,13 @@ static int WriteInodeInfo(FILE *fp, struct ViceInodeInfo *info, char *dir,
  *
  * If the resultFile is NULL, then don't call the write routine.
  */
-int ListViceInodes(char *devname, char *mountedOn, char *resultFile,
-		   int (*judgeInode)(struct ViceInodeInfo *info, int vid),
-		   int singleVolumeNumber, int *forcep,
-		   int forceR, char *wpath)
+int
+ListViceInodes(char *devname, char *mountedOn, char *resultFile,
+	       int (*judgeInode) (struct ViceInodeInfo * info, int vid, void *rock),
+	       int singleVolumeNumber, int *forcep, int forceR, char *wpath, 
+	       void *rock)
 {
-    FILE *fp = (FILE*)-1;
+    FILE *fp = (FILE *) - 1;
     int ninodes;
     struct stat status;
 
@@ -953,8 +1018,9 @@ int ListViceInodes(char *devname, char *mountedOn, char *resultFile,
 	    return -1;
 	}
     }
-    ninodes = nt_ListAFSFiles(wpath, WriteInodeInfo, fp,
-			   judgeInode, singleVolumeNumber);
+    ninodes =
+	nt_ListAFSFiles(wpath, WriteInodeInfo, fp, judgeInode,
+			singleVolumeNumber, rock);
 
     if (!resultFile)
 	return ninodes;
@@ -986,9 +1052,9 @@ int ListViceInodes(char *devname, char *mountedOn, char *resultFile,
 	Log("Unable to successfully stat inode file for %s\n", mountedOn);
 	return -2;
     }
-    if (status.st_size != ninodes * sizeof (struct ViceInodeInfo)) {
-	Log("Wrong size (%d instead of %d) in inode file for %s\n", 
-	    status.st_size, ninodes * sizeof (struct ViceInodeInfo),
+    if (status.st_size != ninodes * sizeof(struct ViceInodeInfo)) {
+	Log("Wrong size (%d instead of %d) in inode file for %s\n",
+	    status.st_size, ninodes * sizeof(struct ViceInodeInfo),
 	    mountedOn);
 	return -2;
     }
@@ -1003,12 +1069,12 @@ int ListViceInodes(char *devname, char *mountedOn, char *resultFile,
  *
  * Returns <0 on error, else number of files found to match.
  */
-int nt_ListAFSFiles(char *dev,
-		    int (*writeFun)(FILE *, struct ViceInodeInfo *, char *,
-				     char *),
-		    FILE *fp,
-		    int (*judgeFun)(struct ViceInodeInfo *, int),
-		    int singleVolumeNumber)
+int
+nt_ListAFSFiles(char *dev,
+		int (*writeFun) (FILE *, struct ViceInodeInfo *, char *,
+				 char *), FILE * fp,
+		int (*judgeFun) (struct ViceInodeInfo *, int, void *),
+		int singleVolumeNumber, void *rock)
 {
     IHandle_t h;
     char name[MAX_PATH];
@@ -1017,19 +1083,18 @@ int nt_ListAFSFiles(char *dev,
     struct dirent *dp;
     static void FreeZLCList(void);
 
-    memset((void*)&h, 0, sizeof(IHandle_t));
+    memset((void *)&h, 0, sizeof(IHandle_t));
     h.ih_dev = toupper(*dev) - 'A';
 
     if (singleVolumeNumber) {
 	h.ih_vid = singleVolumeNumber;
-	if (nt_HandleToVolDir(name, &h)<0)
+	if (!nt_HandleToVolDir(name, &h))
 	    return -1;
-	ninodes = nt_ListAFSSubDirs(&h, writeFun, fp,
-				 judgeFun, singleVolumeNumber);
+	ninodes =
+	    nt_ListAFSSubDirs(&h, writeFun, fp, judgeFun, singleVolumeNumber, rock);
 	if (ninodes < 0)
 	    return ninodes;
-    }
-    else {
+    } else {
 	/* Find all Vol_*.data directories and descend through them. */
 	if (!nt_DevToDrive(name, h.ih_dev))
 	    return -1;
@@ -1039,8 +1104,7 @@ int nt_ListAFSFiles(char *dev,
 	    return -1;
 	while (dp = readdir(dirp)) {
 	    if (!DecodeVolumeName(dp->d_name, &h.ih_vid)) {
-		ninodes += nt_ListAFSSubDirs(&h, writeFun, fp,
-				 judgeFun, 0);
+		ninodes += nt_ListAFSSubDirs(&h, writeFun, fp, judgeFun, 0, rock);
 	    }
 	}
     }
@@ -1058,12 +1122,12 @@ int nt_ListAFSFiles(char *dev,
  * < 0 - an error
  * > = 0 - number of AFS files found.
  */
-static int nt_ListAFSSubDirs(IHandle_t *dirIH,
-			     int (*writeFun)(FILE *, struct ViceInodeInfo *,
-					      char *, char *),
-			     FILE *fp,
-			     int (*judgeFun)(struct ViceInodeInfo *, int),
-			     int singleVolumeNumber)
+static int
+nt_ListAFSSubDirs(IHandle_t * dirIH,
+		  int (*writeFun) (FILE *, struct ViceInodeInfo *, char *,
+				   char *), FILE * fp,
+		  int (*judgeFun) (struct ViceInodeInfo *, int, void *),
+		  int singleVolumeNumber, void *rock)
 {
     int i;
     IHandle_t myIH = *dirIH;
@@ -1077,72 +1141,68 @@ static int nt_ListAFSSubDirs(IHandle_t *dirIH,
     int tag, vno;
     FdHandle_t linkHandle;
     int ninodes = 0;
-    static void AddToZLCDeleteList(char dir, char *name);
     static void DeleteZLCFiles(char *path);
 
     s = nt_HandleToVolDir(path, &myIH);
     strcpy(basePath, path);
-    if (!s) return -1;
+    if (!s)
+	return -1;
     *s = '\\';
     s++;
-    *(s+1) = '\0';
+    *(s + 1) = '\0';
 
     /* Do the directory containing the special files first to pick up link
      * counts.
      */
-    for (i='R'; i>='A'; i--) {
+    for (i = 'R'; i >= 'A'; i--) {
 	*s = (char)i;
-	(void) strcpy(findPath, path);
-	(void) strcat(findPath, "\\*");
-	dirH = FindFirstFileEx(findPath,  FindExInfoStandard, &data,
-			       FindExSearchNameMatch, NULL,
-			       FIND_FIRST_EX_CASE_SENSITIVE);
+	(void)strcpy(findPath, path);
+	(void)strcat(findPath, "\\*");
+	dirH =
+	    FindFirstFileEx(findPath, FindExInfoStandard, &data,
+			    FindExSearchNameMatch, NULL,
+			    FIND_FIRST_EX_CASE_SENSITIVE);
 	if (dirH == INVALID_HANDLE_VALUE)
 	    continue;
 	while (1) {
 	    /* Store the vice info. */
-	    memset((void*)&info, 0, sizeof(info));
+	    memset((void *)&info, 0, sizeof(info));
 	    if (*data.cFileName == '.')
 		goto next_file;
-	    if (DecodeInodeName(data.cFileName, &vno, &tag)<0) {
-		Log("Error parsing %s\\%s\n",
-		       path, data.cFileName);
-	    }
-	    else {
-		info.inodeNumber = (Inode)tag << NT_TAGSHIFT;
-		info.inodeNumber |= (Inode)vno;
+	    if (DecodeInodeName(data.cFileName, &vno, &tag) < 0) {
+		Log("Error parsing %s\\%s\n", path, data.cFileName);
+	    } else {
+		info.inodeNumber = (Inode) tag << NT_TAGSHIFT;
+		info.inodeNumber |= (Inode) vno;
 		info.byteCount = data.nFileSizeLow;
 
-		if (i == 'R') { /* Special inode. */
+		if (i == 'R') {	/* Special inode. */
 		    info.inodeNumber |= NT_INODESPECIAL;
 		    info.u.param[0] = data.ftCreationTime.dwHighDateTime;
-		    info.u.param[1] = data.ftCreationTime.dwLowDateTime; 
+		    info.u.param[1] = data.ftCreationTime.dwLowDateTime;
 		    info.u.param[2] = vno;
 		    info.u.param[3] = dirIH->ih_vid;
 		    if (info.u.param[2] != VI_LINKTABLE) {
 			info.linkCount = 1;
-		    }
-		    else {
+		    } else {
 			/* Open this handle */
 			char lpath[1024];
-			(void) sprintf(lpath, "%s\\%s",
-				       path, data.cFileName);
+			(void)sprintf(lpath, "%s\\%s", path, data.cFileName);
 			linkHandle.fd_fd = nt_open(lpath, O_RDONLY, 0666);
-			info.linkCount = nt_GetLinkCount(&linkHandle,
-							 (Inode)0, 0);
+			info.linkCount =
+			    nt_GetLinkCount(&linkHandle, (Inode) 0, 0);
 		    }
-		}
-		else { /* regular file. */
-		    info.linkCount = nt_GetLinkCount(&linkHandle,
-						     info.inodeNumber, 0);
+		} else {	/* regular file. */
+		    info.linkCount =
+			nt_GetLinkCount(&linkHandle, info.inodeNumber, 0);
 		    if (info.linkCount == 0) {
 #ifdef notdef
 			Log("Found 0 link count file %s\\%s, deleting it.\n",
 			    path, data.cFileName);
 			AddToZLCDeleteList((char)i, data.cFileName);
 #else
-			Log("Found 0 link count file %s\\%s.\n",
-			    path, data.cFileName);
+			Log("Found 0 link count file %s\\%s.\n", path,
+			    data.cFileName);
 #endif
 			goto next_file;
 		    }
@@ -1151,16 +1211,16 @@ static int nt_ListAFSSubDirs(IHandle_t *dirIH,
 		    info.u.param[2] = data.ftCreationTime.dwHighDateTime;
 		    info.u.param[3] = data.ftCreationTime.dwLowDateTime;
 		}
-		if (judgeFun && !(*judgeFun)(&info, singleVolumeNumber))
+		if (judgeFun && !(*judgeFun) (&info, singleVolumeNumber, rock))
 		    goto next_file;
-		if ((*writeFun)(fp, &info, path, data.cFileName)<0) {
+		if ((*writeFun) (fp, &info, path, data.cFileName) < 0) {
 		    nt_close(linkHandle.fd_fd);
 		    FindClose(dirH);
 		    return -1;
 		}
-		ninodes ++;
+		ninodes++;
 	    }
-	next_file:
+	  next_file:
 	    if (!FindNextFile(dirH, &data)) {
 		break;
 	    }
@@ -1178,7 +1238,8 @@ static int nt_ListAFSSubDirs(IHandle_t *dirIH,
 }
 
 /* The name begins with "Vol_" and ends with .data.  See nt_HandleToVolDir() */
-static int DecodeVolumeName(char *name, int *vid)
+static int
+DecodeVolumeName(char *name, int *vid)
 {
     char stmp[32];
     int len;
@@ -1188,30 +1249,33 @@ static int DecodeVolumeName(char *name, int *vid)
 	return -1;
     if (strncmp(name, "Vol_", 4))
 	return -1;
-    if (strcmp(name+len-5, ".data"))
+    if (strcmp(name + len - 5, ".data"))
 	return -1;
     strcpy(stmp, name);
-    stmp[len-5] = '\0';
-    *vid = base32_to_int(stmp+4);
+    stmp[len - 5] = '\0';
+    *vid = base32_to_int(stmp + 4);
     return 0;
 }
 
 /* Recall that the name beings with a "V_" */
-static int DecodeInodeName(char *name, int *p1, int *p2)
+static int
+DecodeInodeName(char *name, int *p1, int *p2)
 {
     char *s, *t;
     char stmp[16];
 
-    (void) strcpy(stmp, name);
+    (void)strcpy(stmp, name);
     s = strrchr(stmp, '_');
-    if (!s) return -1;
+    if (!s)
+	return -1;
     s++;
     t = strrchr(s, '.');
-    if (!t) return -1;
+    if (!t)
+	return -1;
 
     *t = '\0';
     *p1 = base32_to_int(s);
-    *p2 = base32_to_int(t+1);
+    *p2 = base32_to_int(t + 1);
     return 0;
 }
 
@@ -1220,15 +1284,16 @@ static int DecodeInodeName(char *name, int *p1, int *p2)
  *
  * returns a static string used to print either 32 or 64 bit inode numbers.
  */
-char * PrintInode(char *s, Inode ino)
+char *
+PrintInode(char *s, Inode ino)
 {
-    static afs_ino_str_t result; 
+    static afs_ino_str_t result;
     if (!s)
 	s = result;
 
-    (void) sprintf((char*)s, "%I64u", ino);
+    (void)sprintf((char *)s, "%I64u", ino);
 
-    return (char*)s;
+    return (char *)s;
 }
 
 
@@ -1244,7 +1309,8 @@ typedef struct zlcList_s {
 static zlcList_t *zlcAnchor = NULL;
 static zlcList_t *zlcCur = NULL;
 
-static void AddToZLCDeleteList(char dir, char *name)
+static void
+AddToZLCDeleteList(char dir, char *name)
 {
     assert(strlen(name) <= MAX_ZLC_NAMELEN - 3);
 
@@ -1252,13 +1318,12 @@ static void AddToZLCDeleteList(char dir, char *name)
 	if (zlcCur && zlcCur->zlc_next)
 	    zlcCur = zlcCur->zlc_next;
 	else {
-	    zlcList_t *tmp = (zlcList_t*)malloc(sizeof(zlcList_t));
+	    zlcList_t *tmp = (zlcList_t *) malloc(sizeof(zlcList_t));
 	    if (!tmp)
 		return;
 	    if (!zlcAnchor) {
 		zlcAnchor = tmp;
-	    }
-	    else {
+	    } else {
 		zlcCur->zlc_next = tmp;
 	    }
 	    zlcCur = tmp;
@@ -1267,30 +1332,32 @@ static void AddToZLCDeleteList(char dir, char *name)
 	}
     }
 
-    (void) sprintf(zlcCur->zlc_names[zlcCur->zlc_n], "%c\\%s", dir, name);
-    zlcCur->zlc_n ++;
+    (void)sprintf(zlcCur->zlc_names[zlcCur->zlc_n], "%c\\%s", dir, name);
+    zlcCur->zlc_n++;
 }
 
-static void DeleteZLCFiles(char *path)
+static void
+DeleteZLCFiles(char *path)
 {
     zlcList_t *z;
     int i;
     char fname[1024];
 
     for (z = zlcAnchor; z; z = z->zlc_next) {
-	for (i=0; i < z->zlc_n; i++) {
-	    (void) sprintf(fname, "%s\\%s", path, z->zlc_names[i]);
-	    if (nt_unlink(fname)<0) {
+	for (i = 0; i < z->zlc_n; i++) {
+	    (void)sprintf(fname, "%s\\%s", path, z->zlc_names[i]);
+	    if (nt_unlink(fname) < 0) {
 		Log("ZLC: Can't unlink %s, dos error = %d\n", fname,
-		       GetLastError());
+		    GetLastError());
 	    }
 	}
-	z->zlc_n = 0; /* Can reuse space. */
+	z->zlc_n = 0;		/* Can reuse space. */
     }
     zlcCur = zlcAnchor;
 }
 
-static void FreeZLCList(void)
+static void
+FreeZLCList(void)
 {
     zlcList_t *tnext;
     zlcList_t *i;
@@ -1305,4 +1372,3 @@ static void FreeZLCList(void)
 }
 
 #endif /* AFS_NT40_ENV */
-
