@@ -34,10 +34,10 @@ extern pthread_mutex_t vol_fsync_mutex;
 extern pthread_mutex_t vol_trans_mutex;
 extern pthread_cond_t vol_put_volume_cond;
 extern pthread_cond_t vol_sleep_cond;
-#define VATTACH_LOCK \
-    assert(pthread_mutex_lock(&vol_attach_mutex) == 0)
-#define VATTACH_UNLOCK \
-    assert(pthread_mutex_unlock(&vol_attach_mutex) == 0)
+extern int vol_attach_threads;
+/* this lock has been deprecated */
+#define VATTACH_LOCK
+#define VATTACH_UNLOCK
 #define VOL_LOCK \
     assert(pthread_mutex_lock(&vol_glock_mutex) == 0)
 #define VOL_UNLOCK \
